@@ -1,14 +1,14 @@
 #!/bin/sh
-VERSION=`cat xlock/version.h | cut -d\" -f2`
-NAME=xlockmore
-PROG=$NAME-$VERSION
+VERSION=`grep VERSION xlock/version.h | cut -d\" -f2` 2> /dev/null
+NAME="xlockmore"
+PROG="${NAME}-${VERSION}"
 AUTHOR="David Bagley"
 
 if test "$1" = "-p"; then
-	PROG=$NAME
+	PROG=${NAME}
 fi
-PROGZIP=$PROG.tar.xz
-if test "$VERSION" = ""; then
+PROGZIP="${PROG}.tar.xz"
+if test "${VERSION}" = ""; then
 	echo "run from $NAME main directory"
 	exit
 fi
