@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* ant3d --- Extension to Langton's generalized turing machine ants */
-#if !defined( lint ) && !defined( SABER )
+
+#if 0
 static const char sccsid[] = "@(#)ant3d.c	5.13 2004/07/23 xlockmore";
 
 #endif
@@ -30,22 +31,22 @@ static const char sccsid[] = "@(#)ant3d.c	5.13 2004/07/23 xlockmore";
  */
 
 #ifdef STANDALONE
-#define PROGCLASS "Ant3D"
-#define HACK_INIT init_ant3d
-#define HACK_DRAW draw_ant3d
-#define ant3d_opts xlockmore_opts
-#define DEFAULTS "*delay: 5000 \n" \
- "*count: -3 \n" \
- "*cycles: 10000 \n" \
- "*ncolors: 200 \n" \
- "*wireframe: False \n" \
- "*fullrandom: False \n" \
- "*verbose: False \n"
-#include "xlockmore.h"		/* in xscreensaver distribution */
-#else /* STANDALONE */
-#include "xlock.h"		/* in xlockmore distribution */
+# define MODE_ant3d
+# define DEFAULTS	"*delay: 5000 \n" \
+			"*count: -3 \n" \
+			"*cycles: 10000 \n" \
+			"*ncolors: 200 \n" \
+			"*wireframe: False \n" \
+			"*fullrandom: False \n" \
+			"*verbose: False \n"\
 
+# define reshape_ant3d 0
+# define ant3d_handle_event 0
+# include "xlockmore.h"		/* in xscreensaver distribution */
+#else /* STANDALONE */
+# include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#define DO_STIPPLE
 #include "automata.h"
 
 #ifdef MODE_ant3d
@@ -91,13 +92,13 @@ static OptionStruct desc[] =
 	{(char *) "-/+eyes", (char *) "turn on/off eyes"}
 };
 
-ModeSpecOpt ant3d_opts =
+ENTRYPOINT ModeSpecOpt ant3d_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   ant3d_description =
 {"ant3d", "init_ant3d", "draw_ant3d", "release_ant3d",
- "refresh_ant3d", "init_ant3d", NULL, &ant3d_opts,
+ "refresh_ant3d", "init_ant3d", "free_ant3d", &ant3d_opts,
  5000, -3, 10000, 1, 64, 1.0, "",
  "Shows 3D ants", 0, NULL};
 
@@ -106,7 +107,7 @@ ModStruct   ant3d_description =
 #define ANT3DBITS(n,w,h)\
   if ((ap->pixmaps[ap->init_bits]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
-  free_ant3d(display,ap); return;} else {ap->init_bits++;}
+  free_ant3d_screen(display,ap); return;} else {ap->init_bits++;}
 
 /* If you change the table you may have to change the following 2 constants */
 #define STATES 2
@@ -2012,10 +2013,13 @@ DrawScreen(ModeInfo * mi)
 }
 
 static void
-free_ant3d(Display *display, antfarm3dstruct *ap)
+free_ant3d_screen(Display *display, antfarm3dstruct *ap)
 {
 	int shade;
 
+	if (ap == NULL) {
+		return;
+	}
 	if (ap->eraserhead.next != NULL) {
 		End3D(ap);
 	}
@@ -2043,9 +2047,16 @@ free_ant3d(Display *display, antfarm3dstruct *ap)
 		free(ap->ants);
 		ap->ants = (antstruct *) NULL;
 	}
+	ap = NULL;
 }
 
-void
+ENTRYPOINT void
+free_ant3d(ModeInfo * mi)
+{
+	free_ant3d_screen(MI_DISPLAY(mi), &antfarm3ds[MI_SCREEN(mi)]);
+}
+
+ENTRYPOINT void
 init_ant3d(ModeInfo * mi)
 {
 	Display *display = MI_DISPLAY(mi);
@@ -2053,14 +2064,11 @@ init_ant3d(ModeInfo * mi)
 	antfarm3dstruct *ap;
 	int i;
 
-	if (antfarm3ds == NULL) {
-		if ((antfarm3ds = (antfarm3dstruct *) calloc(MI_NUM_SCREENS(mi),
-				sizeof (antfarm3dstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, antfarm3ds);
 	ap = &antfarm3ds[MI_SCREEN(mi)];
 
 	ap->nInvisible = 0;
+#ifdef DO_STIPPLE
 	if (MI_NPIXELS(mi) <= 2) {
 		if (ap->stippledGC == None) {
 			XGCValues   gcv;
@@ -2068,7 +2076,7 @@ init_ant3d(ModeInfo * mi)
 			gcv.fill_style = FillOpaqueStippled;
 			if ((ap->stippledGC = XCreateGC(display, window,
 					GCFillStyle, &gcv)) == None) {
-				free_ant3d(display, ap);
+				free_ant3d_screen(display, ap);
 				return;
 			}
 		}
@@ -2078,6 +2086,7 @@ init_ant3d(ModeInfo * mi)
 			}
 		}
 	}
+#endif /* DO_STIPPLE */
 	ap->generation = 0;
 	ap->n = MI_COUNT(mi);
 	if (ap->n < -MINANTS) {
@@ -2136,7 +2145,7 @@ init_ant3d(ModeInfo * mi)
 	if ((ap->tape = (unsigned char *) calloc(
 			ap->ncols * ap->nrows * ap->nstacks,
 			sizeof (unsigned char))) == NULL) {
-		free_ant3d(display, ap);
+		free_ant3d_screen(display, ap);
 		return;
 	}
 	ap->width = MI_WIDTH(mi);
@@ -2157,14 +2166,14 @@ init_ant3d(ModeInfo * mi)
 	if (ap->ants == NULL) {
 		if ((ap->ants = (antstruct *) malloc(ap->n *
 				sizeof (antstruct))) == NULL) {
-			free_ant3d(display, ap);
+			free_ant3d_screen(display, ap);
 			return;
 		}
 	}
 	if (ap->antList == NULL) {
 		if ((ap->antList = (antstruct **) malloc(ap->n *
 				sizeof (antstruct *))) == NULL) {
-			free_ant3d(display, ap);
+			free_ant3d_screen(display, ap);
 			return;
 		}
 	}
@@ -2200,7 +2209,7 @@ init_ant3d(ModeInfo * mi)
 	}
 	if ((ap->dbuf = XCreatePixmap(display, window,
 		ap->width, ap->height, MI_DEPTH(mi))) == None) {
-		free_ant3d(display, ap);
+		free_ant3d_screen(display, ap);
 		return;
 	}
 	if (MI_IS_FULLRANDOM(mi)) {
@@ -2211,7 +2220,7 @@ init_ant3d(ModeInfo * mi)
 	DrawScreen(mi);
 }
 
-void
+ENTRYPOINT void
 draw_ant3d(ModeInfo * mi)
 {
 	antfarm3dstruct *ap;
@@ -2238,20 +2247,21 @@ draw_ant3d(ModeInfo * mi)
 		ap->painted = True;
 }
 
-void
+ENTRYPOINT void
 release_ant3d(ModeInfo * mi)
 {
 	if (antfarm3ds != NULL) {
 		int         screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_ant3d(MI_DISPLAY(mi), &antfarm3ds[screen]);
+			free_ant3d_screen(MI_DISPLAY(mi), &antfarm3ds[screen]);
 		free(antfarm3ds);
 		antfarm3ds = (antfarm3dstruct *) NULL;
 	}
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_ant3d(ModeInfo * mi)
 {
 	antfarm3dstruct *ap;
@@ -2264,5 +2274,8 @@ refresh_ant3d(ModeInfo * mi)
 		MI_CLEARWINDOW(mi);
 	}
 }
+#endif
+
+XSCREENSAVER_MODULE ("Ant3d", ant3d)
 
 #endif /* MODE_ant3d */
