@@ -31,7 +31,7 @@
 #define SECOND			""
 #define SECONDS			""
 
-#if METRIC
+#ifdef METRIC
 #define AREA_STRING		"إ"
 #else
 #define AREA_STRING		""
