@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* atunnels --- OpenGL Advanced Tunnel Screensaver */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)atunnels.c	5.13 2004/07/19 xlockmore";
 #endif
 
@@ -43,48 +43,41 @@ static const char sccsid[] = "@(#)atunnels.c	5.13 2004/07/19 xlockmore";
 #endif
 
 #ifdef STANDALONE		/* xscreensaver mode */
-# define PROGCLASS		"Atunnels"
-# define HACK_INIT		init_atunnels
-# define HACK_DRAW		draw_atunnels
-# define HACK_RESHAPE		reshape_atunnels
-# define atunnels_opts		xlockmore_opts
+# define MODE_atunnels
 #define	DEFAULTS                "*delay:	10000	\n" \
-				"*showFPS:     	False	\n" \
-                                "*light:	True	\n" \
-                                "*wire:		False	\n" \
-                                "*texture:	True	\n"
+				"*showFPS:     	False	\n"
 
 # include "xlockmore.h"		/* from the xscreensaver distribution */
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#define free_atunnels 0
+#define atunnels_handle_event 0
 #else /* !STANDALONE */
 # include "xlock.h"		/* from the xlockmore distribution */
 # include "visgl.h"
 #endif /* !STANDALONE */
 
-#ifdef USE_GL /* whole file */
-
+#ifdef MODE_atunnels
 #include "tunnel_draw.h"
 
 #ifdef HAVE_XPM
 #include "xpm-ximage.h"
 
-#ifdef STANDALONE
+#if 0
 #include "../images/tunnel0.xpm"
 #include "../images/tunnel1.xpm"
 #include "../images/tunnel2.xpm"
 #include "../images/tunnel3.xpm"
 #include "../images/tunnel4.xpm"
 #include "../images/tunnel5.xpm"
-#else /* !STANDALONE */
+#endif
 #include "pixmaps/tunnel0.xpm"
 #include "pixmaps/tunnel1.xpm"
 #include "pixmaps/tunnel2.xpm"
 #include "pixmaps/tunnel3.xpm"
 #include "pixmaps/tunnel4.xpm"
 #include "pixmaps/tunnel5.xpm"
-#endif /* !STANDALONE */
 #endif /* HAVE_XPM */
 
 #undef countof
@@ -121,13 +114,14 @@ static OptionStruct desc[] =
   {(char *)"-/+ texture", (char *)"whether to apply a texture (slower)"},
 };
 
-ModeSpecOpt atunnels_opts = {countof(opts), opts, countof(vars), vars, desc};
+ENTRYPOINT ModeSpecOpt atunnels_opts =
+{countof(opts), opts, countof(vars), vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   atunnels_description =
 {"atunnels", "init_atunnels", "draw_atunnels", "release_atunnels",
- "draw_atunnels", "init_atunnels", NULL, &atunnels_opts,
- 25000, 1, 1, 1, 0, 1.0, "",
+ "draw_atunnels", "change_atunnels", NULL, &atunnels_opts,
+ 25000, 1, 1, 0, 64, 1.0, "",
  "Shows an OpenGL advanced tunnel screensaver", 0, NULL};
 #endif
 
@@ -166,8 +160,12 @@ static Bool LoadTexture(ModeInfo * mi, char **fn, int t_num)
 	clear_gl_error();
 	glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, teximage->width, teximage->height,
 			0, GL_RGBA, GL_UNSIGNED_BYTE, teximage->data);
+#ifdef STANDALONE
+	check_gl_error("texture");
+#else
 	if (check_gl_error("texture"))
 		return False;
+#endif
 
 	/* Texture parameters, LINEAR scaling for better texture quality */
 	glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
@@ -253,7 +251,7 @@ static Bool Init(ModeInfo * mi)
 
 
 /* Standard reshape function */
-void
+static void
 reshape_atunnels(ModeInfo *mi, int width, int height)
 {
 	float a;
@@ -267,7 +265,8 @@ reshape_atunnels(ModeInfo *mi, int width, int height)
 }
 
 /* draw the screensaver once */
-void draw_atunnels(ModeInfo * mi)
+ENTRYPOINT void
+draw_atunnels(ModeInfo * mi)
 {
   	atunnelsstruct *gp;
   	Display    *display = MI_DISPLAY(mi);
@@ -296,23 +295,15 @@ void draw_atunnels(ModeInfo * mi)
 
 }
 
-void
-refresh_atunnels(ModeInfo * mi)
-{
-}
-
-
 /* xscreensaver initialization routine */
-void init_atunnels(ModeInfo * mi)
+ENTRYPOINT void
+init_atunnels(ModeInfo * mi)
 {
   int screen = MI_SCREEN(mi);
   int size = MI_SIZE(mi);
   atunnelsstruct *gp;
 
-  if (Atunnels == NULL) {
-	if ((Atunnels = (atunnelsstruct *) calloc(MI_NUM_SCREENS(mi), sizeof (atunnelsstruct))) == NULL)
-	  return;
-  }
+  MI_INIT(mi, Atunnels);
   gp = &Atunnels[screen];
 
   /* Viewport is specified size if size >= MINSIZE && size < screensize */
@@ -338,7 +329,8 @@ void init_atunnels(ModeInfo * mi)
 }
 
 /* all sorts of nice cleanup code should go here! */
-void release_atunnels(ModeInfo * mi)
+ENTRYPOINT void
+release_atunnels(ModeInfo * mi)
 {
   if (Atunnels != NULL) {
 #if 0
@@ -353,9 +345,10 @@ void release_atunnels(ModeInfo * mi)
   }
   FreeAllGL(mi);
 }
-#endif
 
-void change_atunnels(ModeInfo * mi)
+#ifndef STANDALONE
+ENTRYPOINT void
+change_atunnels(ModeInfo * mi)
 {
   	atunnelsstruct *gp;
 
@@ -371,4 +364,8 @@ void change_atunnels(ModeInfo * mi)
 #endif
 	(void) Init(mi);
 }
+#endif
 
+XSCREENSAVER_MODULE ("Atunnels", atunnels)
+
+#endif /* MODE_atunnels */
