@@ -1,5 +1,5 @@
-/* juggle, Copyright (c) 1996-2009 Tim Auckland <tda10.geo@yahoo.com>
- * and Jamie Zawinski <jwz@jwz.org>
+/* juggle, Copyright (c) 1996-2009 Tim Auckland <tda10.geo AT yahoo.com>
+ * and Jamie Zawinski <jwz AT jwz.org>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -31,7 +31,7 @@
  *              implementation, so that different objects can have
  *              different length trails.
  * 11-Nov-2004: [TDA] Clap when all the balls are in the air.
- * 10-Nov-2004: [TDA] Display pattern name converted to hight
+ * 10-Nov-2004: [TDA] Display pattern name converted to height
  *              notation.
  * 31-Oct-2004: [TDA] Add -clubs and new trail implementation.
  * 02-Sep-2003: Non-real time to see what is happening without a
@@ -128,17 +128,11 @@
 #undef MEMTEST
 
 #ifdef VMS
-#include "vms_x_fix.h"
-#include <X11/Intrinsic.h>
+#include <types.h>
 #endif
 
 #ifdef STANDALONE
 #define MODE_juggler3d
-#define PROGCLASS       "Juggler3D"
-#define HACK_INIT       init_juggler3d
-#define HACK_DRAW       draw_juggler3d
-#define HACK_RESHAPE    reshape_juggler3d
-#define juggler3d_opts     xlockmore_opts
 # define DEFAULTS	"*delay:	10000	\n" \
 			"*count:	200	\n" \
 			"*cycles:	1000	\n" \
@@ -148,10 +142,11 @@
 			"*wireframe:	False	\n"
 #include "xlockmore.h"
 #define refresh_juggler3d 0
+#define free_juggler3d 0
 
-#define MI_COLOR_red    ((MI)->colors->red)
-#define MI_COLOR_green    ((MI)->colors->green)
-#define MI_COLOR_blue    ((MI)->colors->blue)
+#define MI_COLOR_red    ((mi)->colors[color].red)
+#define MI_COLOR_green    ((mi)->colors[color].green)
+#define MI_COLOR_blue    ((mi)->colors[color].blue)
 
 /* TODO for JWZ: move this to better place */
 #define MI_POLYGONCOUNT(MI)    ((MI)->polygon_count)
@@ -165,7 +160,7 @@
 #define MI_COLOR_blue    (NRAND(50000)+15536)
 #endif /* !STANDALONE */
 
-#ifdef MODE_juggler3d
+#ifdef MODE_juggler3d /* whole file */
 
 #undef countof
 #define countof(x) (sizeof((x))/sizeof((*x)))
@@ -174,10 +169,13 @@
 #include "tube.h"
 #include "rotator.h"
 #include "gltrackball.h"
+#ifdef STANDALONE
+#include "texfont.h"
+#else
 #include "glxfonts.h"
+#endif
 #include <ctype.h>
 
-#ifdef USE_GL /* whole file */
 #include <GL/glu.h>
 
 #define DEF_PATTERN "random" /* All patterns */
@@ -623,9 +621,12 @@ typedef struct {
   ObjType       objtypes;
   Object_j       *objects;
   struct patternindex patternindex;
-
+#ifdef STANDALONE
+  texture_font_data *font_data;
+#else
   XFontStruct *mode_font;
   GLuint font_dlist;
+#endif
 } jugglestruct;
 
 static jugglestruct *juggles = (jugglestruct *) NULL;
@@ -683,7 +684,10 @@ trajectory_destroy(Trajectory *t) {
 }
 
 static void
-free_juggler3d(jugglestruct *sp) {
+free_juggler3d_screen(jugglestruct *sp) {
+  if (sp == NULL) {
+	return;
+  }
   if (sp->head != NULL) {
 	while (sp->head->next != sp->head) {
 	  trajectory_destroy(sp->head->next);
@@ -702,17 +706,26 @@ free_juggler3d(jugglestruct *sp) {
 	free(sp->pattern);
 	sp->pattern = NULL;
   }
-  if (sp->mode_font!=None) {
-	XFreeFontInfo(NULL,sp->mode_font,1);
+#ifdef STANDALONE
+  if (sp->font_data != NULL) {
+        free_texture_font(sp->font_data);
+	sp->font_data = NULL;
+  }
+#else
+  if (sp->mode_font != None) {
+	XFreeFontInfo(NULL, sp->mode_font, 1);
 	sp->mode_font = None;
   }
+#endif
   if (sp->rot != NULL) {
 	free_rotator(sp->rot);
+	sp->rot = NULL;
   }
   if (sp->trackball != NULL) {
 	free (sp->trackball);
 	sp->trackball = NULL;
   }
+  sp = NULL;
 }
 
 static Bool
@@ -722,7 +735,7 @@ add_throw(jugglestruct *sp, char type, int h, Notation n, const char* name)
 
   ADD_ELEMENT(Trajectory, t, sp->head->prev);
   if(t == NULL){ /* Out of Memory */
-	free_juggler3d(sp);
+	free_juggler3d_screen(sp);
 	return False;
   }
   t->object = NULL;
@@ -963,7 +976,7 @@ part(jugglestruct *sp)
 	  t->action = CATCH;
 	  ADD_ELEMENT(Trajectory, nt, p);
 	  if(nt == NULL){
-		free_juggler3d(sp);
+		free_juggler3d_screen(sp);
 		return False;
 	  }
 	  nt->object = NULL;
@@ -993,7 +1006,7 @@ choose_object(void) {
   return o;
 }
 
-/* Connnect up throws and catches to figure out which ball goes where.
+/* Connect up throws and catches to figure out which ball goes where.
    Do the same with the juggler's hands. */
 
 static void
@@ -1555,7 +1568,7 @@ hands(jugglestruct *sp)
 	  continue;
 	}
 
-	/* double spline takes hand from throw, thru catch, to
+	/* double spline takes hand from throw, through catch, to
 	   next throw */
 
 	t->finish = u->start;
@@ -2491,7 +2504,7 @@ release_juggler3d (ModeInfo * mi)
 	int screen;
 
 	for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-	  free_juggler3d(&juggles[screen]);
+		free_juggler3d_screen(&juggles[screen]);
 	free(juggles);
 	juggles = (jugglestruct *) NULL;
   }
@@ -2623,7 +2636,7 @@ refill_juggle(ModeInfo * mi)
   positions(sp);
 
   if (!projectile(sp)) {
-	free_juggler3d(sp);
+	free_juggler3d_screen(sp);
 	return;
   }
 
@@ -2664,7 +2677,7 @@ change_juggler3d(ModeInfo * mi)
 }
 
 
-ENTRYPOINT void
+static void
 reshape_juggler3d (ModeInfo *mi, int width, int height)
 {
   GLfloat h = (GLfloat) height / (GLfloat) width;
@@ -2692,8 +2705,7 @@ init_juggler3d (ModeInfo * mi)
   int wire = MI_IS_WIREFRAME(mi);
 
   if (!juggles) {
-    juggles = (jugglestruct *)
-      calloc (MI_NUM_SCREENS(mi), sizeof (jugglestruct));
+    MI_INIT(mi, juggles);
 #ifdef STANDALONE
     if (!juggles) {
       fprintf(stderr, "%s: out of memory\n", progname);
@@ -2705,8 +2717,13 @@ init_juggler3d (ModeInfo * mi)
   sp = &juggles[MI_SCREEN(mi)];
   sp->glx_context = init_GL(mi);
 
+#ifdef STANDALONE
+  if (!sp->glx_context)   /* re-initting breaks print_texture_label */
+    sp->glx_context = init_GL(mi);
+  sp->font_data = load_texture_font (mi->dpy, "titleFont");
+#else 
   load_font (MI_DISPLAY(mi), (char *) "titleFont",  &sp->mode_font, &sp->font_dlist);
-
+#endif
   reshape_juggler3d (mi, MI_WIDTH(mi), MI_HEIGHT(mi));
 
   if (!wire)
@@ -2737,7 +2754,7 @@ init_juggler3d (ModeInfo * mi)
     double spin_accel   = 0.05;
     sp->rot = make_rotator (0, spin_speed, 0, 
                             spin_accel, wander_speed, False);
-    sp->trackball = gltrackball_init ();
+    sp->trackball = gltrackball_init (True);
   }
 
   if (only && *only && strcmp(only, " ")) {
@@ -2791,14 +2808,14 @@ init_juggler3d (ModeInfo * mi)
 	/* create circular trajectory list */
 	ADD_ELEMENT(Trajectory, sp->head, sp->head);
 	if(sp->head == NULL){
-	  free_juggler3d(sp);
+	  free_juggler3d_screen(sp);
 	  return;
 	}
 
 	/* create circular object list */
 	ADD_ELEMENT(Object_j, sp->objects, sp->objects);
 	if(sp->objects == NULL){
-	  free_juggler3d(sp);
+	  free_juggler3d_screen(sp);
 	  return;
 	}
 
@@ -2856,8 +2873,8 @@ init_juggler3d (ModeInfo * mi)
 
 }
 
-ENTRYPOINT Bool
-juggle_handle_event (ModeInfo *mi, XEvent *event)
+static Bool
+juggler3d_handle_event (ModeInfo *mi, XEvent *event)
 {
   jugglestruct *sp = &juggles[MI_SCREEN(mi)];
 
@@ -2992,7 +3009,7 @@ draw_juggler3d (ModeInfo *mi)
   for (traj = sp->head->next; traj != sp->head; traj = traj->next) {
 	if (traj->status != PREDICTOR) {
 	  /* Skip any elements that need further processing */
-	  /* We could remove them, but there shoudn't be many and they
+	  /* We could remove them, but there shouldn't be many and they
 		 would be needed if we ever got the pattern refiller
 		 working */
 	  continue;
@@ -3098,14 +3115,19 @@ draw_juggler3d (ModeInfo *mi)
 					 MI_SCREEN(mi), sp->pattern);
 	}
   }
-
+#ifdef STANDALONE
+  glColor3f (1, 1, 0);
+  print_texture_label (mi->dpy, sp->font_data,
+                     mi->xgwa.width, mi->xgwa.height,
+                     1, sp->pattern);
+#else
   if(sp->mode_font != None) {
     print_gl_string (MI_DISPLAY(mi), sp->mode_font, sp->font_dlist,
                      MI_WIDTH(mi), MI_HEIGHT(mi),
                      10, MI_HEIGHT(mi) - 10,
                      sp->pattern, False);
   }
-
+#endif
 #ifdef MEMTEST
   if((int)(sp->time/10) % 1000 == 0)
 	(void) fprintf(stderr, "sbrk: %d\n", (int)sbrk(0));
@@ -3126,9 +3148,9 @@ draw_juggler3d (ModeInfo *mi)
   glXSwapBuffers(dpy, window);
 }
 
-#if STANDALONE
+/*#ifdef STANDALONE
 XSCREENSAVER_MODULE_2 ("Juggler3D", juggler3d, juggle)
-#endif
+#endif*/
+XSCREENSAVER_MODULE ("Juggler3d", juggler3d)
 
-#endif /* USE_GL */
 #endif /* MODE_juggler3d */
