@@ -1,9 +1,8 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* moebius --- Moebius Strip II, an Escher-like GL scene with ants. */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
-
 #endif
 
 /*-
@@ -25,7 +24,7 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  *     Second Edition" Pag. 227, exercise 5.15.
  *
  * This mode shows some interesting scenes that are impossible OR very
- * wierd to build in the real universe. Much of the scenes are inspirated
+ * weird to build in the real universe. Much of the scenes are inspirated
  * on Mauritz Cornelis Escher's works which derivated the mode's name.
  * M.C. Escher (1898-1972) was a dutch artist and many people prefer to
  * say he was a mathematician.
@@ -37,7 +36,7 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  * mistakes.
  *
  * My e-mail address is
- * mfvianna@centroin.com.br
+ * mfvianna AT centroin.com.br
  *
  * Marcelo F. Vianna (Jun-01-1997)
  *
@@ -45,7 +44,7 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  * 05-Apr-2002: Removed all gllist uses (fix some bug with nvidia driver)
  * 01-Mar-2001: backported from xscreensaver by lassauge AT users.sourceforge.net
  *    Feb-2001: Made motion and rotation be smoother Jamie Zawinski
- *              <jwz@jwz.org>
+ *              <jwz AT jwz.org>
  * 01-Nov-2000: Allocation checks
  * 01-Jan-1998: Mode separated from escher and renamed
  * 08-Jun-1997: New scene implemented: "Impossible Cage" based in a M.C.
@@ -59,7 +58,7 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  *              Marcelo F. Vianna.
  * 03-Jun-1997: Initial Release (Only one scene: "Moebius Strip")
  *              The Moebius Strip scene was inspirated in a M.C. Escher's
- *              painting named Moebius Strip II in wich ants walk across a
+ *              painting named Moebius Strip II in which ants walk across a
  *              Moebius Strip path, sometimes meeting each other and sometimes
  *              being in "opposite faces" (note that the moebius strip has
  *              only one face and one edge).
@@ -71,7 +70,7 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  * visuals DO NOT support texture mapping in OpenGL.
  *
  * BUT Mesa do implements RGBA contexts in pseudo color visuals, so texture
- * mapping shuld work on PseudoColor, DirectColor, TrueColor using Mesa. Mono
+ * mapping should work on PseudoColor, DirectColor, TrueColor using Mesa. Mono
  * is not officially supported for both OpenGL and Mesa, but seems to not crash
  * Mesa.
  *
@@ -79,20 +78,18 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  */
 
 #ifdef VMS
-#include <X11/Intrinsic.h>
+#include <types.h>
 #endif
 
 #ifdef STANDALONE
 # define MODE_moebius
-# define PROGCLASS			"Moebius"
-# define HACK_INIT			init_moebius
-# define HACK_DRAW			draw_moebius
-# define HACK_RESHAPE			reshape_moebius
-# define moebius_opts			xlockmore_opts
 # define DEFAULTS			"*cycles:	1       \n"	\
 					"*delay:	30000   \n"	\
 					"*showFps:      False   \n"	\
 					"*wireframe:	False	\n"
+
+# define free_moebius 0
+# define moebius_handle_event 0
 # include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
 # include "xlock.h"		/* from the xlockmore distribution */
@@ -129,14 +126,14 @@ static OptionStruct desc[] =
 	{(char *) "-/+noants", (char *) "turn on/off walking ants"}
 };
 
-ModeSpecOpt moebius_opts =
+ENTRYPOINT ModeSpecOpt moebius_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   moebius_description =
 {"moebius", "init_moebius", "draw_moebius", "release_moebius",
  "draw_moebius", "change_moebius", (char *) NULL, &moebius_opts,
- 30000, 1, 1, 1, 4, 1.0, "",
+ 30000, 1, 1, 1, 64, 1.0, "",
  "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL};
 
 #endif
@@ -617,7 +614,9 @@ pinit(void)
 
 
 /* lifted from lament.c */
+#ifndef RANDSIGN
 #define RANDSIGN() ((LRAND() & 1) ? 1 : -1)
+#endif
 #define FLOATRAND(a) (((double)LRAND() / (double)MAXRAND) * a)
 
 static void
@@ -692,7 +691,7 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
     }
 }
 
-void
+ENTRYPOINT void
 release_moebius(ModeInfo * mi)
 {
 	if (moebius != NULL) {
@@ -702,16 +701,12 @@ release_moebius(ModeInfo * mi)
 	FreeAllGL(mi);
 }
 
-void
+ENTRYPOINT void
 init_moebius(ModeInfo * mi)
 {
 	moebiusstruct *mp;
 
-	if (moebius == NULL) {
-		if ((moebius = (moebiusstruct *) calloc(MI_NUM_SCREENS(mi),
-					    sizeof (moebiusstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, moebius);
 	mp = &moebius[MI_SCREEN(mi)];
 	mp->step = NRAND(90);
 	mp->ant_position = NRAND(90);
@@ -743,7 +738,7 @@ init_moebius(ModeInfo * mi)
 	}
 }
 
-void
+ENTRYPOINT void
 draw_moebius(ModeInfo * mi)
 {
 	moebiusstruct *mp;
@@ -806,7 +801,8 @@ draw_moebius(ModeInfo * mi)
 	mp->step += 0.025;
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 change_moebius(ModeInfo * mi)
 {
 	moebiusstruct *mp = &moebius[MI_SCREEN(mi)];
@@ -821,5 +817,8 @@ change_moebius(ModeInfo * mi)
 #endif
 	pinit();
 }
-
 #endif
+
+XSCREENSAVER_MODULE ("Moebius", moebius)
+
+#endif /* MODE_moebius */
