@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* loop --- Chris Langton's self-producing loops */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)loop.c	5.24 2007/01/18 xlockmore";
 
 #endif
@@ -85,7 +85,7 @@ ping.
    machine is not contained in the loop.  This is a simplification of
    von Neumann and Codd's self-producing Turing machine.
    The data spinning around could be viewed as both its DNA and its internal
-   clock.  The program can be initalized to have the loop spin both ways...
+   clock.  The program can be initialized to have the loop spin both ways...
    but only one way around will work for a given rule.  An open question (at
    least to me): Is handedness a requirement for (artificial) life?  Here
    there is handedness at both the initial condition and the transition rule.
@@ -93,20 +93,20 @@ ping.
 
 #ifdef STANDALONE
 #define MODE_loop
-#define PROGCLASS "loop"
-#define HACK_INIT init_loop
-#define HACK_DRAW draw_loop
-#define loop_opts xlockmore_opts
 #define DEFAULTS "*delay: 100000 \n" \
- "*count: -5 \n" \
- "*cycles: 1600 \n" \
- "*size: -12 \n" \
- "*ncolors: 15 \n" \
- "*neighbors: 0 \n"
+	"*count: -5 \n" \
+	"*cycles: 1600 \n" \
+	"*size: -12 \n" \
+	"*ncolors: 15 \n" \
+
+# define free_loop 0
+# define reshape_loop 0
+# define loop_handle_event 0
 #define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
+#define DO_STIPPLE
 #endif /* STANDALONE */
 #include "automata.h"
 
@@ -188,7 +188,7 @@ static OptionStruct desc[] =
 	{(char *) "-/+vertical", (char *) "change orientation for hexagons"}
 };
 
-ModeSpecOpt loop_opts =
+ENTRYPOINT ModeSpecOpt loop_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 
@@ -204,7 +204,7 @@ ModStruct   loop_description =
 #define LOOPBITS(n,w,h)\
   if ((lp->pixmaps[lp->init_bits]=\
   XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
-  free_loop(display,lp); return;} else {lp->init_bits++;}
+  free_loop_screen(display,lp); return;} else {lp->init_bits++;}
 
 static int  local_neighbors = 0;
 
@@ -303,9 +303,6 @@ typedef struct {
 
 static loopstruct *loops = (loopstruct *) NULL;
 
-static const int M8[]={1, 8, 64, 512, 4096, 32768, 262144, 2097152, 16777216};
-static const int M9[]={1, 9, 81, 729, 6561, 59049, 531441, 4782969, 43046721,
-	387420489};
 /*#define INEF2 1*/
 #ifndef INEF2
 #define TRANSITION(TT,V) V=TT&7;TT>>=3
@@ -313,15 +310,20 @@ static const int M9[]={1, 9, 81, 729, 6561, 59049, 531441, 4782969, 43046721,
 #define TABLE(R,T,L,B) (table[((B)<<9)|((L)<<6)|((T)<<3)|(R)])
 #define TABLE_OUT(C,R,T,L,B) ((TABLE(R,T,L,B)>>((C)*3))&7)
 #else
+static const int M8[]={1, 8, 64, 512, 4096, 32768, 262144, 2097152, 16777216};
 #define TRANSITION(TT,V) V=TT%8;TT/=8
 #define FINALTRANSITION(TT,V) V=TT%8
 #define TABLE(R,T,L,B) (table[((B)*512)+((L)*64)+((T)*8)+(R)])
 #define TABLE_OUT(C,R,T,L,B) ((TABLE(R,T,L,B)/(M8[C]))%8)
 #endif
+#if 0
+static const int M9[]={1, 9, 81, 729, 6561, 59049, 531441, 4782969, 43046721,
+	387420489};
 #define EXT_TRANSITION(TT,V) V=TT%9;TT/=9
 #define EXT_FINALTRANSITION(TT,V) V=TT%9
 #define EXT_TABLE(R,T,L,B) (table[((B)*729)+((L)*81)+((T)*9)+(R)])
 #define EXT_TABLE_OUT(C,R,T,L,B) ((EXT_TABLE(R,T,L,B)/(M9[C]))%9)
+#endif
 #define INEF_TABLE_OUT(C,R,T,L,B) table[(B)*6561+(L)*729+(T)*81+(R)*9+(C)]
 #define HEX_TABLE(R,T,t,l,b,B) (table[((B)<<15)|((b)<<12)|((l)<<9)|((t)<<6)|((T)<<3)|(R)])
 #define HEX_TABLE_OUT(C,R,T,t,l,b,B) ((HEX_TABLE(R,T,t,l,b,B)>>((C)*3))&7)
@@ -337,8 +339,10 @@ static const int M9[]={1, 9, 81, 729, 6561, 59049, 531441, 4782969, 43046721,
 #ifdef RAND_RULES
 #define TABLE_IN(C,R,T,L,B,I) (TABLE(R,T,L,B)&=~(7<<((C)*3)));\
 (TABLE(R,T,L,B)|=((I)<<((C)*3)))
+#if 0
 #define EXT_TABLE_IN(C,R,T,L,B,I) (EXT_TABLE(R,T,L,B)-=(9*M9[C]-1));\
 (EXT_TABLE(R,T,L,B)+=((I)*(M9[C])))
+#endif
 #define HEX_TABLE_IN(C,R,T,t,l,b,B,I) (HEX_TABLE(R,T,t,l,b,B)&=~(7<<((C)*3)));\
 (HEX_TABLE(R,T,t,l,b,B)|=((I)<<((C)*3)))
 #else
@@ -347,7 +351,9 @@ static const int M9[]={1, 9, 81, 729, 6561, 59049, 531441, 4782969, 43046721,
 #else
 #define TABLE_IN(C,R,T,L,B,I) if(TABLE_OUT(C,R,T,L,B)==0) (TABLE(R,T,L,B)+=((I)*(M8[C])))
 #endif
+#if 0
 #define EXT_TABLE_IN(C,R,T,L,B,I) if (EXT_TABLE_OUT(C,R,T,L,B)==0) (EXT_TABLE(R,T,L,B)+=((I)*(M9[C])))
+#endif
 #define HEX_TABLE_IN(C,R,T,t,l,b,B,I) (HEX_TABLE(R,T,t,l,b,B)|=((I)<<((C)*3)))
 #endif
 #define INEF_TABLE_IN(C,R,T,L,B,I) INEF_TABLE_OUT(C,R,T,L,B)=(I)
@@ -928,7 +934,7 @@ static unsigned int hexTransitionTable[] =
     000270270, 000007020, 000040270,
 
     /* Collision starts (gen 540), not sure to have rules to save it
-       or depend on calloc to intialize remaining rules to 0 so that
+       or depend on calloc to initialize remaining rules to 0 so that
        the mutant will be born
      */
     000050220,
@@ -1299,10 +1305,13 @@ free_cells(loopstruct * lp)
 }
 
 static void
-free_loop(Display *display, loopstruct * lp)
+free_loop_screen(Display *display, loopstruct * lp)
 {
 	int         shade;
 
+	if (lp == NULL) {
+		return;
+	}
 	for (shade = 0; shade < lp->init_bits; shade++)
 		if (lp->pixmaps[shade] != None) {
 			XFreePixmap(display, lp->pixmaps[shade]);
@@ -1314,6 +1323,7 @@ free_loop(Display *display, loopstruct * lp)
 		lp->stippledGC = None;
 	}
 	free_cells(lp);
+	lp = NULL;
 }
 
 static Bool
@@ -1325,7 +1335,7 @@ addtolist(ModeInfo * mi, int col, int row, unsigned char state)
 	if ((lp->cellList[state] = (CellList *) malloc(sizeof (CellList))) ==
 			NULL) {
 		lp->cellList[state] = current;
-		free_loop(MI_DISPLAY(mi), lp);
+		free_loop_screen(MI_DISPLAY(mi), lp);
 		return False;
 	}
 	lp->cellList[state]->pt.x = col;
@@ -1412,7 +1422,7 @@ draw_state(ModeInfo * mi, int state)
 	SHEATHCOUNT(d) + SHEATHCOUNT(e)) >= 2)
 
 static void
-setUndefinedRule()
+setUndefinedRule(void)
 {
 	int a, b, c, d, e;
 
@@ -1515,7 +1525,7 @@ setUndefinedRule()
 }
 
 static void
-setUndefinedEvoRule()
+setUndefinedEvoRule(void)
 {
 	int a, b, c, d, e;
 
@@ -1844,7 +1854,7 @@ init_flaw(ModeInfo * mi)
 }
 
 static int
-sqAdamLoopX()
+sqAdamLoopX(void)
 {
 	if (byl) {
 		return BYL_ADAM_LOOPX;
@@ -1858,7 +1868,7 @@ sqAdamLoopX()
 }
 
 static int
-sqAdamLoopY()
+sqAdamLoopY(void)
 {
 	if (byl) {
 		return BYL_ADAM_LOOPY;
@@ -2189,14 +2199,14 @@ do_gen(loopstruct * lp)
 	}
 }
 
-void
+ENTRYPOINT void
 release_loop(ModeInfo * mi)
 {
 	if (loops != NULL) {
 		int         screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_loop(MI_DISPLAY(mi), &loops[screen]);
+			free_loop_screen(MI_DISPLAY(mi), &loops[screen]);
 		free(loops);
 		loops = (loopstruct *) NULL;
 	}
@@ -2207,7 +2217,7 @@ release_loop(ModeInfo * mi)
 	local_neighbors = 0;
 }
 
-void
+ENTRYPOINT void
 init_loop(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -2216,11 +2226,7 @@ init_loop(ModeInfo * mi)
 	loopstruct *lp;
 	XGCValues   gcv;
 
-	if (loops == NULL) {
-		if ((loops = (loopstruct *) calloc(MI_NUM_SCREENS(mi),
-				sizeof (loopstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, loops);
 	lp = &loops[MI_SCREEN(mi)];
 
 	lp->redrawing = 0;
@@ -2232,7 +2238,7 @@ init_loop(ModeInfo * mi)
 			gcv.fill_style = FillOpaqueStippled;
 			if ((lp->stippledGC = XCreateGC(display, window,
 				 GCFillStyle, &gcv)) == None) {
-				free_loop(display, lp);
+				free_loop_screen(display, lp);
 				return;
 			}
 		}
@@ -2357,12 +2363,12 @@ init_loop(ModeInfo * mi)
 
 	if ((lp->oldcells = (unsigned char *) calloc(lp->bncols * lp->bnrows,
 			sizeof (unsigned char))) == NULL) {
-		free_loop(display, lp);
+		free_loop_screen(display, lp);
 		return;
 	}
 	if ((lp->newcells = (unsigned char *) calloc(lp->bncols * lp->bnrows,
 			sizeof (unsigned char))) == NULL) {
-		free_loop(display, lp);
+		free_loop_screen(display, lp);
 		return;
 	}
 	if (!init_table(mi)) {
@@ -2388,7 +2394,7 @@ init_loop(ModeInfo * mi)
 	init_adam(mi);
 }
 
-void
+ENTRYPOINT void
 draw_loop(ModeInfo * mi)
 {
 	int         offset, i, j, factor = 1;
@@ -2441,7 +2447,7 @@ draw_loop(ModeInfo * mi)
 	}
 	for (i = 0; i < EXT_STATES; i++)
 		if (!draw_state(mi, i)) {
-			free_loop(MI_DISPLAY(mi), lp);
+			free_loop_screen(MI_DISPLAY(mi), lp);
 			return;
 		}
 	if (byl | chou1 | chou2)
@@ -2467,7 +2473,8 @@ draw_loop(ModeInfo * mi)
 	}
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_loop(ModeInfo * mi)
 {
 	loopstruct *lp;
@@ -2480,5 +2487,8 @@ refresh_loop(ModeInfo * mi)
 	lp->redrawing = 1;
 	lp->redrawpos = lp->by * lp->ncols + lp->bx;
 }
+#endif
+
+XSCREENSAVER_MODULE ("Loop", loop)
 
 #endif /* MODE_loop */
