@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* swirl --- swirly patterns */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)swirl.c	5.09 2003/06/30 xlockmore";
 
 #endif
@@ -26,7 +26,7 @@ static const char sccsid[] = "@(#)swirl.c	5.09 2003/06/30 xlockmore";
  *              xscreensaver's starfish, looks like I am not going to
  *              port the variable speed colormapping when done drawing.
  * 01-Nov-2000: Allocation checks
- * 13-May-1997: jwz@jwz.org: turned into a standalone program.
+ * 13-May-1997: jwz AT jwz.org: turned into a standalone program.
  * 21-Apr-1995: improved startup time for TrueColour displays
  *              (limited to 16bpp to save memory) S.Early <sde1000@cam.ac.uk>
  * 09-Jan-1995: fixed colour maps (more colourful) and the image now spirals
@@ -38,13 +38,13 @@ static const char sccsid[] = "@(#)swirl.c	5.09 2003/06/30 xlockmore";
 
 #ifdef STANDALONE
 #define MODE_swirl
-#define PROGCLASS "Swirl"
-#define HACK_INIT init_swirl
-#define HACK_DRAW draw_swirl
-#define swirl_opts xlockmore_opts
 #define DEFAULTS "*delay: 5000 \n" \
- "*count: 5 \n" \
- "*ncolors: 200 \n"
+	"*count: 5 \n" \
+	"*ncolors: 200 \n" \
+
+# define free_swirl 0
+# define reshape_swirl 0
+# define swirl_handle_event 0
 #define SMOOTH_COLORS
 #define WRITABLE_COLORS
 #include "xlockmore.h"		/* from the xscreensaver distribution */
@@ -75,7 +75,7 @@ static OptionStruct desc[] =
   {(char *) "-/+cycle", (char *) "turn on/off colour cycling"}
 };
 
-ModeSpecOpt swirl_opts =
+ENTRYPOINT ModeSpecOpt swirl_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
@@ -125,7 +125,7 @@ typedef enum {
 
 /* data associated with a swirl window */
 typedef struct swirl_data {
-	/* window paramaters */
+	/* window parameters */
 	int         width, height;	/* window size */
 	int         depth;	/* depth */
 	int         rdepth;	/* real depth (for XImage) */
@@ -164,7 +164,6 @@ typedef struct swirl_data {
 	XColor     *colors;
 	int         ncolors;
 	Bool        cycle_p, mono_p, no_colors, reverse;
-	ModeInfo   *mi;
 } swirlstruct;
 
 /* an array of swirls for each screen */
@@ -188,10 +187,13 @@ random_no(unsigned int n)
 /****************************************************************/
 
 static void
-free_swirl(Display *display, swirlstruct *sp)
+free_swirl_screen(ModeInfo *mi, swirlstruct *sp)
 {
-  ModeInfo *mi = sp->mi;
+	Display *display = MI_DISPLAY(mi);
 
+	if (sp == NULL) {
+		return;
+	}
 	if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
 		MI_WHITE_PIXEL(mi) = sp->whitepixel;
 		MI_BLACK_PIXEL(mi) = sp->blackpixel;
@@ -200,9 +202,17 @@ free_swirl(Display *display, swirlstruct *sp)
 		MI_BG_PIXEL(mi) = sp->bg;
 #endif
 		if (sp->colors != NULL) {
+#ifdef STANDALONE
+			Screen *screen = MI_SCREENPTR(mi);
+#endif
 			if (sp->ncolors && !sp->no_colors)
-				free_colors(display, sp->cmap, sp->colors,
-					sp->ncolors);
+				free_colors(
+#ifdef STANDALONE
+					screen,
+#else
+					display,
+#endif
+					sp->cmap, sp->colors, sp->ncolors);
 			free(sp->colors);
 			sp->colors = (XColor *) NULL;
 		}
@@ -223,6 +233,7 @@ free_swirl(Display *display, swirlstruct *sp)
 		free(sp->knots);
 		sp->knots = (KNOT_P) NULL;
 	}
+	sp = NULL;
 }
 
 #ifndef STANDALONE
@@ -447,7 +458,7 @@ create_knots(swirlstruct *sp)
  * Returns the value of the point
  */
 static unsigned long
-do_point(swirlstruct *sp, int i, int j)
+do_point(ModeInfo *mi, swirlstruct *sp, int i, int j)
 {
 	int         tT, k, add, value;
 	unsigned long colour_value;
@@ -455,7 +466,6 @@ do_point(swirlstruct *sp, int i, int j)
 	int         ncolours, qcolours;
 	double      rads;
 	KNOT_P      knot;
-	ModeInfo   *mi = sp->mi;
 
 	/* how many colours? */
 	ncolours = sp->ncolors;
@@ -628,13 +638,13 @@ draw_point(ModeInfo * mi, swirlstruct *sp)
 		r2 = r / 2;
 
 		/* interleave blocks at half r */
-		draw_block(sp->ximage, x, y, r2, do_point(sp, x, y));
-		draw_block(sp->ximage, x + r2, y, r2, do_point(sp, x + r2, y));
-		draw_block(sp->ximage, x + r2, y + r2, r2, do_point(sp,
+		draw_block(sp->ximage, x, y, r2, do_point(mi, sp, x, y));
+		draw_block(sp->ximage, x + r2, y, r2, do_point(mi, sp, x + r2, y));
+		draw_block(sp->ximage, x + r2, y + r2, r2, do_point(mi, sp,
 							    x + r2, y + r2));
-		draw_block(sp->ximage, x, y + r2, r2, do_point(sp, x, y + r2));
+		draw_block(sp->ximage, x, y + r2, r2, do_point(mi, sp, x, y + r2));
 	} else
-		draw_block(sp->ximage, x, y, r, do_point(sp, x, y));
+		draw_block(sp->ximage, x, y, r, do_point(mi, sp, x, y));
 
 	/* update the screen */
 /*-
@@ -751,7 +761,7 @@ next_point(swirlstruct *sp)
  *
  * -      win is the window to draw in
  */
-void
+ENTRYPOINT void
 init_swirl(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -760,20 +770,15 @@ init_swirl(ModeInfo * mi)
 
 	/* does the swirls array exist? */
 	if (swirls == NULL) {
-		int         i;
-
-		/* allocate an array, one entry for each screen */
-		if ((swirls = (swirlstruct *) calloc(MI_NUM_SCREENS(mi),
-				sizeof (swirlstruct))) == NULL)
-			return;
+		int i;
 
+		MI_INIT(mi, swirls);
 		/* initialise them all */
 		for (i = 0; i < MI_NUM_SCREENS(mi); i++)
 			initialise_swirl(&swirls[i]);
 	}
 	/* get a pointer to this swirl */
 	sp = &(swirls[MI_SCREEN(mi)]);
-	sp->mi = mi;
 
 	/* get window parameters */
 	sp->width = MI_WIDTH(mi);
@@ -787,7 +792,7 @@ init_swirl(ModeInfo * mi)
 
 	/* initialise image for speeding up drawing */
 	if (!initialise_image(display, sp)) {
-		free_swirl(display, sp);
+		free_swirl_screen(mi, sp);
 		return;
 	}
 	MI_CLEARWINDOW(mi);
@@ -804,7 +809,7 @@ init_swirl(ModeInfo * mi)
 			sp->whitepixel = MI_WHITE_PIXEL(mi);
 			if ((sp->cmap = XCreateColormap(display, window,
 					MI_VISUAL(mi), AllocNone)) == None) {
-				free_swirl(display, sp);
+				free_swirl_screen(mi, sp);
 				return;
 			}
 			XSetWindowColormap(display, window, sp->cmap);
@@ -827,7 +832,7 @@ init_swirl(ModeInfo * mi)
 		}
 		if ((sp->gc = XCreateGC(display, MI_WINDOW(mi),
 			     (unsigned long) 0, (XGCValues *) NULL)) == None) {
-			free_swirl(display, sp);
+			free_swirl_screen(mi, sp);
 			return;
 		}
 	}
@@ -836,9 +841,18 @@ init_swirl(ModeInfo * mi)
   /* Set up colour map */
   sp->direction = (LRAND() & 1) ? 1 : -1;
   if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
+#ifdef STANDALONE
+	Screen *screen = MI_SCREENPTR(mi);
+#endif
     if (sp->colors != NULL) {
       if (sp->ncolors && !sp->no_colors)
-        free_colors(display, sp->cmap, sp->colors, sp->ncolors);
+	free_colors(
+#ifdef STANDALONE
+		screen,
+#else
+		display,
+#endif
+		sp->cmap, sp->colors, sp->ncolors);
       free(sp->colors);
       sp->colors = (XColor *) NULL;
     }
@@ -855,10 +869,16 @@ init_swirl(ModeInfo * mi)
     else
       if ((sp->colors = (XColor *) malloc(sizeof (*sp->colors) *
           (sp->ncolors + 1))) == NULL) {
-        free_swirl(display, sp);
+        free_swirl_screen(mi, sp);
         return;
       }
-    sp->cycle_p = has_writable_cells(mi);
+    sp->cycle_p = has_writable_cells(
+#ifdef STANDALONE
+	screen, MI_VISUAL(mi)
+#else
+	mi
+#endif
+	);
     if (sp->cycle_p) {
       if (MI_IS_FULLRANDOM(mi)) {
         if (!NRAND(8))
@@ -872,31 +892,40 @@ init_swirl(ModeInfo * mi)
     if (!sp->mono_p) {
       if (!(LRAND() % 10))
         make_random_colormap(
-#if STANDALONE
-            display, MI_WINDOW(mi),
+#ifdef STANDALONE
+		screen, MI_VISUAL(mi),
+		sp->cmap, sp->colors, &sp->ncolors,
+		True, True, &sp->cycle_p, True
 #else
-            mi,
+		mi,
+		sp->cmap, sp->colors, &sp->ncolors,
+		True, True, &sp->cycle_p
 #endif
-              sp->cmap, sp->colors, &sp->ncolors,
-              True, True, &sp->cycle_p);
+		);
       else if (!(LRAND() % 2))
         make_uniform_colormap(
-#if STANDALONE
-            display, MI_WINDOW(mi),
+#ifdef STANDALONE
+		screen, MI_VISUAL(mi),
+		sp->cmap, sp->colors, &sp->ncolors,
+		True, &sp->cycle_p, True
 #else
-            mi,
+		mi,
+		sp->cmap, sp->colors, &sp->ncolors,
+		True, &sp->cycle_p
 #endif
-                  sp->cmap, sp->colors, &sp->ncolors,
-                  True, &sp->cycle_p);
+		);
       else
         make_smooth_colormap(
-#if STANDALONE
-            display, MI_WINDOW(mi),
+#ifdef STANDALONE
+		screen, MI_VISUAL(mi),
+		sp->cmap, sp->colors, &sp->ncolors,
+		True, &sp->cycle_p, True
 #else
-            mi,
+		mi,
+		sp->cmap, sp->colors, &sp->ncolors,
+		True, &sp->cycle_p
 #endif
-                 sp->cmap, sp->colors, &sp->ncolors,
-                 True, &sp->cycle_p);
+		);
     }
     XInstallColormap(display, sp->cmap);
     if (sp->ncolors < 2) {
@@ -920,7 +949,7 @@ init_swirl(ModeInfo * mi)
 	/* resolution starts off chunky */
 	sp->resolution = MIN_RES + 1;
 
-	/* calculate the pixel step for this resulution */
+	/* calculate the pixel step for this resolution */
 	sp->r = (1 << (sp->resolution - 1));
 
 	/* how many knots? */
@@ -939,7 +968,7 @@ init_swirl(ModeInfo * mi)
 
 	/* fix the knot values */
 	if (!create_knots(sp)) {
-		free_swirl(display, sp);
+		free_swirl_screen(mi, sp);
 		return;
 	}
 
@@ -957,7 +986,7 @@ init_swirl(ModeInfo * mi)
  *
  * -      win is the window to draw in
  */
-void
+ENTRYPOINT void
 draw_swirl(ModeInfo * mi)
 {
 	swirlstruct *sp;
@@ -975,7 +1004,13 @@ draw_swirl(ModeInfo * mi)
 		/* in the middle of drawing? */
 		if (sp->drawing) {
 		  if(sp->cycle_p) {
-		 rotate_colors(MI_DISPLAY(mi), sp->cmap, sp->colors, sp->ncolors, sp->direction);
+		 rotate_colors(
+#ifdef STANDALONE
+			MI_SCREENPTR(mi),
+#else
+			MI_DISPLAY(mi),
+#endif
+			sp->cmap, sp->colors, sp->ncolors, sp->direction);
 		    if (!(LRAND() % 1000))
       sp->direction = -sp->direction;
                  }
@@ -993,7 +1028,13 @@ draw_swirl(ModeInfo * mi)
 			}
 		} else {
 		  if(sp->cycle_p) {
-		 rotate_colors(MI_DISPLAY(mi), sp->cmap, sp->colors, sp->ncolors, sp->direction);
+		 rotate_colors(
+#ifdef STANDALONE
+			MI_SCREENPTR(mi),
+#else
+			MI_DISPLAY(mi),
+#endif
+			sp->cmap, sp->colors, sp->ncolors, sp->direction);
 		    if (!(LRAND() % 1000))
       sp->direction = -sp->direction;
                  }
@@ -1003,7 +1044,7 @@ draw_swirl(ModeInfo * mi)
 				/* move to higher resolution */
 				sp->resolution--;
 
-				/* calculate the pixel step for this resulution */
+				/* calculate the pixel step for this resolution */
 				sp->r = (1 << (sp->resolution - 1));
 
 				/* start drawing again */
@@ -1038,7 +1079,7 @@ draw_swirl(ModeInfo * mi)
 
 /****************************************************************/
 
-void
+ENTRYPOINT void
 release_swirl(ModeInfo * mi)
 {
 	/* does the swirls array exist? */
@@ -1047,7 +1088,7 @@ release_swirl(ModeInfo * mi)
 
 		/* free them all */
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_swirl(MI_DISPLAY(mi), &swirls[screen]);
+			free_swirl_screen(mi, &swirls[screen]);
 		/* deallocate an array, one entry for each screen */
 		free(swirls);
 		swirls = (swirlstruct *) NULL;
@@ -1056,7 +1097,8 @@ release_swirl(ModeInfo * mi)
 
 /****************************************************************/
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_swirl(ModeInfo * mi)
 {
 	swirlstruct *sp;
@@ -1072,5 +1114,8 @@ refresh_swirl(ModeInfo * mi)
 		sp->drawing = False;
 	}
 }
+#endif
+
+XSCREENSAVER_MODULE ("Swirl", swirl)
 
 #endif /* MODE_swirl */
