@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* wator --- Dewdney's Wa-Tor, water torus simulation */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)wator.c	5.24 2007/01/18 xlockmore";
 
 #endif
@@ -34,15 +34,14 @@ static const char sccsid[] = "@(#)wator.c	5.24 2007/01/18 xlockmore";
 
 #ifdef STANDALONE
 #define MODE_wator
-#define PROGCLASS "Wator"
-#define HACK_INIT init_wator
-#define HACK_DRAW draw_wator
-#define wator_opts xlockmore_opts
 #define DEFAULTS "*delay: 750000 \n" \
- "*cycles: 32767 \n" \
- "*size: 0 \n" \
- "*ncolors: 200 \n" \
- "*neighbors: 0 \n"
+	"*cycles: 32767 \n" \
+	"*size: 0 \n" \
+	"*ncolors: 200 \n" \
+
+# define free_wator 0
+# define reshape_wator 0
+# define wator_handle_event 0
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -79,7 +78,7 @@ static OptionStruct desc[] =
 	{(char *) "-/+vertical", (char *) "change orientation for hexagons and triangles"}
 };
 
-ModeSpecOpt wator_opts =
+ENTRYPOINT ModeSpecOpt wator_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
@@ -146,7 +145,7 @@ typedef struct {
 	int         col, row;
 } cellstruct;
 
-/* Doublely linked list */
+/* Doubly linked list */
 typedef struct _CellList {
 	cellstruct  info;
 	struct _CellList *previous, *next;
@@ -156,7 +155,7 @@ typedef struct {
 	Bool        painted, vertical;
 	int         nkind[KINDS];	/* Number of fish and sharks */
 	int         breed[KINDS];	/* Breeding time of fish and sharks */
-	int         sstarve;	/* Time the sharks starve if they dont find a fish */
+	int         sstarve;	/* Time the sharks starve if they don't find a fish */
 	int         kind;	/* Currently working on fish or sharks? */
 	int         xs, ys;	/* Size of fish and sharks */
 	int         xb, yb;	/* Bitmap offset for fish and sharks */
@@ -836,10 +835,13 @@ positionOfNeighbor(watorstruct * wp, int n, int col, int row)
 }
 
 static void
-free_wator(watorstruct *wp)
+free_wator_screen(watorstruct *wp)
 {
 	int kind;
 
+	if (wp == NULL) {
+		return;
+	}
 	for (kind = 0; kind <= KINDS; kind++) {
 		if (wp->firstkind[kind] != NULL) {
 			flush_kindlist(wp, kind);
@@ -855,9 +857,10 @@ free_wator(watorstruct *wp)
 		free(wp->arr);
 		wp->arr = (CellList **) NULL;
 	}
+	wp = NULL;
 }
 
-void
+ENTRYPOINT void
 init_wator(ModeInfo * mi)
 {
 	int         size = MI_SIZE(mi);
@@ -865,11 +868,7 @@ init_wator(ModeInfo * mi)
 	cellstruct  info;
 	watorstruct *wp;
 
-	if (wators == NULL) {
-		if ((wators = (watorstruct *) calloc(MI_NUM_SCREENS(mi),
-					      sizeof (watorstruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, wators);
 	wp = &wators[MI_SCREEN(mi)];
 
 	wp->generation = 0;
@@ -880,7 +879,7 @@ init_wator(ModeInfo * mi)
 		   doubly linked list, doubly linked to an array */
 		for (kind = FISH; kind <= KINDS; kind++)
 			if (!init_kindlist(wp, kind)) {
-				free_wator(wp);
+				free_wator_screen(wp);
 				return;
 			}
 		for (i = 0; i < BITMAPS; i++) {
@@ -1052,7 +1051,7 @@ init_wator(ModeInfo * mi)
 		free(wp->arr);
 	if ((wp->arr = (CellList **) calloc(wp->positions,
 			sizeof (CellList *))) == NULL) {
-		free_wator(wp);
+		free_wator_screen(wp);
 		return;
 	}
 
@@ -1092,7 +1091,7 @@ init_wator(ModeInfo * mi)
 				info.col = col;
 				info.row = row;
 				if (!addto_kindlist(wp, kind, info)) {
-					free_wator(wp);
+					free_wator_screen(wp);
 					return;
 				}
 				wp->arr[colrow] = wp->currkind;
@@ -1103,7 +1102,7 @@ init_wator(ModeInfo * mi)
 	}
 }
 
-void
+ENTRYPOINT void
 draw_wator(ModeInfo * mi)
 {
 	int         col, row;
@@ -1164,7 +1163,7 @@ draw_wator(ModeInfo * mi)
 						cutfrom_kindlist(wp);	/* This rotates out who goes first */
 						wp->babykind->info.age = 0;
 						if (!dupin_kindlist(wp)) {
-							free_wator(wp);
+							free_wator_screen(wp);
 							return;
 						}
 						wp->arr[colrow] = wp->babykind;
@@ -1223,7 +1222,7 @@ draw_wator(ModeInfo * mi)
 						cutfrom_kindlist(wp);	/* This rotates out who goes first */
 						wp->babykind->info.age = 0;
 						if (!dupin_kindlist(wp)) {
-							free_wator(wp);
+							free_wator_screen(wp);
 							return;
 						}
 						wp->arr[colrow] = wp->babykind;
@@ -1258,20 +1257,21 @@ draw_wator(ModeInfo * mi)
 		wp->generation++;
 }
 
-void
+ENTRYPOINT void
 release_wator(ModeInfo * mi)
 {
 	if (wators != NULL) {
 		int         screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_wator(&wators[screen]);
+			free_wator_screen(&wators[screen]);
 		free(wators);
 		wators = (watorstruct *) NULL;
 	}
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_wator(ModeInfo * mi)
 {
 	watorstruct *wp;
@@ -1285,5 +1285,8 @@ refresh_wator(ModeInfo * mi)
 		wp->painted = False;
 	}
 }
+#endif
+
+XSCREENSAVER_MODULE ("Wator", wator)
 
 #endif /* MODE_wator */
