@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* Xapi --- mapped X API calls */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)Xapi.c	4.07 98/04/16 xlockmore";
 
 #endif
@@ -14,6 +14,7 @@ static const char sccsid[] = "@(#)Xapi.c	4.07 98/04/16 xlockmore";
 
 #define NUMBER_GC		(1024)
 #define NUMBER_BITMAP	(1024)
+#define WINDOW_DEPTH	(8) /* incorrect, but we'll set it to 8 */
 
 typedef struct {
 	unsigned long	background;
@@ -62,6 +63,7 @@ typedef struct {
 typedef struct {
 	int				isActive;
 	int				needsReset;
+	int				depth;
 	TColor			color;
 	TFillRule		fillRule;
 	TFillStyle		fillStyle;
@@ -83,7 +85,7 @@ typedef struct {
 
 /* -------------------------------------------------------------------- */
 
-int GCCreate(void);
+int GCCreate(Drawable d);
 HDC GCGetDC(Drawable d, GC gc);
 int BMInfoCreate(void);
 HBITMAP DrawableGetBitmap(Drawable d);
@@ -292,7 +294,7 @@ LCreateBitmap(XImage *image, HBITMAP *hBitmap, HPALETTE *hPalette)
 /* the following functions to create, destroy, modify and access the 
    GC Info structure
  */
-int GCCreate(void)
+int GCCreate(Drawable d)
 {
 	int	retVal		= 0;
 
@@ -307,6 +309,8 @@ int GCCreate(void)
 
 	gcInfo[retVal].isActive = TRUE;
 	gcInfo[retVal].needsReset = TRUE;
+	gcInfo[retVal].depth =
+		d > 0 && d < NUMBER_BITMAP ? bmInfo[d].type : WINDOW_DEPTH;
 	gcInfo[retVal].color.background = NUMCOLORS+1;
 	gcInfo[retVal].color.foreground = NUMCOLORS;
 	gcInfo[retVal].fillRule.hasFillRule = FALSE;
@@ -362,7 +366,7 @@ HDC GCGetDC(Drawable d, GC gc)
 	if (d > 0 && d < NUMBER_BITMAP)
 	{
 		if (dbhdc == NULL)
-			/* create a compatible DC from the saved intial DC. To draw
+			/* create a compatible DC from the saved initial DC. To draw
 			   to this DC we still need to put a HBITMAP into it (not 
 			   done in this function)
 			 */
@@ -1178,13 +1182,14 @@ Colormap XCopyColormapAndFree(Display *display, Colormap colormap)
 
 /*-
  *  XCopyPlane
- *    to be implemented
+ *    copies a single plane of one drawable to another
  */
 int XCopyPlane(Display *display, Drawable src, Drawable dest, GC gc,
 			  int src_x, int src_y, unsigned width, int height, 
 			  int dest_x, int dest_y, unsigned long plane)
 {
-	return 0;
+	return XCopyArea(display, src, dest, gc,
+					 src_x, src_y, width, height, dest_x, dest_y);
 }
 
 /*-
@@ -1253,25 +1258,13 @@ GC XCreateGC(Display *display, Drawable drawable,
 	GC		newGc;
 	char	message[80];
 
-	if ((newGc = GCCreate()) == -1)
+	if ((newGc = GCCreate(drawable)) == -1)
 	{
 		sprintf(message, "Failed to create a GC");
 		xlockmore_set_debug(message);
 	}
 	else
 	{
-		/* check if drawable is a bitmap, and adjust the 1 and 0 colors
-		   (white and black) to their proper win32 values */
-		if (drawable > 0 && drawable < NUMBER_BITMAP)
-			if (bmInfo[drawable].isActive == TRUE && bmInfo[drawable].type == 1)
-			{
-				if (valuemask & GCBackground)
-					if (values->background == 0 || values->background == 1)
-						values->background = 256 + values->background;
-				if (valuemask & GCForeground)
-					if (values->foreground == 0 || values->foreground == 1)
-						values->foreground = 256 + values->foreground;
-			}
 		XChangeGC(display, newGc, valuemask, values);
 	}
 
@@ -1453,7 +1446,7 @@ void XDrawArc(Display *display, Drawable d, GC gc, int x, int y,
 
 	if (angle2 == 0) {
 		/* Special case - In X this is a point but Arc in Windows would
-		   do a complete elipse!  Draw a (thick) line instead.  */
+		   do a complete ellipse!  Draw a (thick) line instead.  */
 	  
 		XDrawLine(display, d, gc, xa1, ya1, xa1, ya1);
 
@@ -1794,7 +1787,7 @@ void XFillArc(Display *display, Drawable d, GC gc, int x, int y,
 
 	if (angle2 == 0) {
 	  /* Special case - In X this is a point but Arc in Windows would
-		 do a complete elipse!  Draw a (thick) line instead.  */
+		 do a complete ellipse!  Draw a (thick) line instead.  */
 	  
 	  XDrawLine(display, d, gc, cx, cy, xa1, ya1);
 
@@ -1865,7 +1858,7 @@ void XFillArcs(Display *display, Drawable d, GC gc,
 
 		if (arcs[i].angle2 == 0) {
 		  /* Special case - In X this is a point but Arc in Windows would
-			 do a complete elipse!  Draw a (thick) line instead.  */
+			 do a complete ellipse!  Draw a (thick) line instead.  */
 		  
 		  XDrawLine(display, d, gc, cx, cy, xa1, ya1);
 
@@ -2183,7 +2176,7 @@ Status XGetWindowAttributes(Display *display, Window w,
 
 	window_attr_return->width = rc.right;
 	window_attr_return->height = rc.bottom;
-	window_attr_return->depth = 8; /* incorrect, but we'll set it to 8 */
+	window_attr_return->depth = WINDOW_DEPTH;
 	window_attr_return->root = (int)hwnd;
 
 	return 0;
@@ -2596,6 +2589,15 @@ void XSetBackground(Display *display, GC gc, unsigned long background)
 	if (gc >= 0 && gc < numGCInfo && gcInfo[gc].isActive == TRUE)
 	{
 		gcInfo[gc].needsReset = TRUE;
+
+		/* check if drawable is a bitmap, and adjust the 1 and 0 colors
+		   (white and black) to their proper win32 values */
+		if (gcInfo[gc].depth == 1)
+		{
+			if (background == 0 || background == 1)
+				background = 256 + background;
+		}
+
 		/* check that the background is in range */
 		if (background > (NUMCOLORS+1))
 			gcInfo[gc].color.background = NUMCOLORS-1;
@@ -2648,7 +2650,7 @@ void XSetFont(Display *display, GC gc, Font font)
 
 /*-
  *  XSetForeground
- *    sets the color of the current color, forground pen and
+ *    sets the color of the current color, foreground pen and
  *    brush
  */
 void XSetForeground(Display *display, GC gc, unsigned long foreground)
@@ -2656,6 +2658,15 @@ void XSetForeground(Display *display, GC gc, unsigned long foreground)
 	if (gc >= 0 && gc < numGCInfo && gcInfo[gc].isActive == TRUE)
 	{
 		gcInfo[gc].needsReset = TRUE;
+
+		/* check if drawable is a bitmap, and adjust the 1 and 0 colors
+		   (white and black) to their proper win32 values */
+		if (gcInfo[gc].depth == 1)
+		{
+			if (foreground == 0 || foreground == 1)
+				foreground = 256 + foreground;
+		}
+
 		/* check that the foreground is in range */
 		if (foreground > (NUMCOLORS+1))
 			gcInfo[gc].color.foreground = NUMCOLORS-1;
