@@ -24,7 +24,7 @@
   XgLock Problems are almost the same as XmLock's ones.
     1. Allowing only one in -inroot.  Need a way to kill it. (a menu ?)
     2. Still missing many options (TO DO).
-    3. Need a clean rewritting.
+    3. Need a clean rewriting.
  */
 
 #include <sys/types.h>
@@ -60,6 +60,7 @@
 #define FORK_STR                        "fork"
 #endif
 
+#include <X11/Xlib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
@@ -210,7 +211,7 @@ secured_realloc(gpointer ptr,
  * compose_xlock_command
  * ---------------------
  * This function scan the string passed as argument to see if
- * it is necessary to suround it with quotes for using it as a command
+ * it is necessary to surround it with quotes for using it as a command
  * line argument.
  */
 static gchar *
@@ -428,7 +429,7 @@ compose_xlock_command(gchar ***cmd_argv_p,
 /*
  * kill_xlock_cb
  * -------------
- * Callback associated wih the Kill xlock file menu entry
+ * Callback associated with the Kill xlock file menu entry
  */
 static void
 kill_xlock_cb(GtkWidget *w,
@@ -592,7 +593,7 @@ static void
 bool_option_clicked_cb(GtkWidget *w,
                        gpointer udata )
 {
-    guint optnr =(guint)udata;
+    guint optnr = GPOINTER_TO_UINT(udata);
 
     if ( !( GTK_IS_CHECK_BUTTON(w) )) return;
 
@@ -621,7 +622,7 @@ static void
 mode_list_item_select_cb(GtkWidget *w,
                          gpointer mode_nr )
 {
-    gint mode =(gint)mode_nr;
+    gint mode = GPOINTER_TO_INT(mode_nr);
     gint i;
 
     if (w->state != GTK_STATE_SELECTED ) return;
@@ -1149,7 +1150,7 @@ about_dialog(GtkWidget *w,
          "Updates by Eric Lassauge <lassauge@users.sourceforge.net>.\n\n"
 #endif
          "GTK+ launcher for xlockmore: the maintained version of xlock.\n"
- 	 "http://www.tux.org/~bagleyd/xlockmore.html\n"
+ 	 "https://www.sillycycle.com/xlockmore.html\n"
 	 "Version 3.0\n";
 
   xlabel = gtk_label_new(text);
@@ -1488,6 +1489,7 @@ static void
 create_boolOptions_buttons(GtkScrolledWindow *parent)
 {
     gint         i;
+    gpointer     iptr = 0;
     GtkWidget   *box0;
     GtkWidget   *box1;
     GtkWidget   *box2;
@@ -1512,7 +1514,7 @@ create_boolOptions_buttons(GtkScrolledWindow *parent)
         gtk_box_pack_start(GTK_BOX(i%2 ? box1 : box2), button, TRUE, TRUE, 0);
         gtk_signal_connect(GTK_OBJECT(button), "clicked",
                            (GtkSignalFunc) bool_option_clicked_cb,
-                           (gpointer)i);
+                           iptr++);
         gtk_widget_show(button);
     }
 }
@@ -1549,6 +1551,7 @@ main(gint argc, gchar *argv[])
     gint        i;
     gchar       temp[100];
 
+    XInitThreads();
     /* Init for some data */
     nb_mode = sizeof (LockProcs) / sizeof (LockProcs[0]);
     nb_boolOpt = sizeof (BoolOpt) / sizeof (BoolOpt[0]);
