@@ -1,4 +1,4 @@
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)iostuff.c	5.03 2001/11/16 xlockmore";
 
 #endif
@@ -10,10 +10,10 @@ static const char sccsid[] = "@(#)iostuff.c	5.03 2001/11/16 xlockmore";
  *
  * Revision History:
  *
- * Changes maintained by David Bagley <bagleyd@tux.org>
+ * Changes maintained by David Bagley <bagleyd AT verizon.net>
  * 16-Nov-2001: Keep same sel_image wildcard behavior as xlockmore 5.02 except
- *              on VMS so it works for directories. <tschmidt@micron.com>
- * 29-Oct-2001: Bug fix for sel_image by Jouk Jansen <joukj@hrem.stm.tudelft.nl>
+ *              on VMS so it works for directories. <tschmidt AT micron.com>
+ * 29-Oct-2001: Bug fix for sel_image by Jouk Jansen <joukj AT hrem.nano.tudelft.nl>
  *              It treated wildcards like wild*.* as being *wild*.*.
  * 23-Apr-1998: Separated out of util.c
  *
@@ -507,7 +507,7 @@ getImage(ModeInfo * mi, XImage ** logo,
 				MI_BITMAP(mi));
 			return;
 		}
-		(void) strncpy(bitmap_local, MI_BITMAP(mi), 256);
+		(void) strncpy(bitmap_local, MI_BITMAP(mi), 255);
 #if HAVE_DIRENT_H
 		getRandomFile(MI_BITMAP(mi), bitmap_local);
 #endif
@@ -716,7 +716,7 @@ getPixmap(ModeInfo * mi, Drawable drawable,
 				MI_BITMAP(mi));
 			return;
 		}
-		(void) strncpy(bitmap_local, MI_BITMAP(mi), 256);
+		(void) strncpy(bitmap_local, MI_BITMAP(mi), 255);
 #if HAVE_DIRENT_H
 		getRandomFile(MI_BITMAP(mi), bitmap_local);
 #endif
@@ -745,7 +745,7 @@ getModeFont(char *infont)
 				infont);
 			return (char *) NULL;
 		}
-		(void) strncpy(localfont, infont, 256);
+		(void) strncpy(localfont, infont, 255);
 #if HAVE_DIRENT_H
 		getRandomFile(infont, localfont);
 #endif
@@ -786,7 +786,7 @@ isRibbon(void)
 	return (getwordsfrom == FROM_RESRC);
 }
 
-#if !defined(__cplusplus) && !defined(c_plusplus)
+#if !defined(WIN32) && !defined(__cplusplus) && !defined(c_plusplus)
 extern int  pclose(FILE *);
 #endif
 
@@ -1019,9 +1019,17 @@ getFontSet(Display * display)
 	int n_miss;
 	XFontSet fs;
 
-	fs = XCreateFontSet(display,
-			    DEF_MESSAGEFONTSET,
-			    &miss, &n_miss, &def);
+	if ((fs = XCreateFontSet(display,
+			(messagefontname) ? messagefontname : DEF_MESSAGEFONT,
+			&miss, &n_miss, &def)) == NULL) {
+		if (messagefontname) {
+			(void) fprintf(stderr, "can not find font: %s, using %s...\n",
+				messagefontname, DEF_MESSAGEFONT);
+			fs = XCreateFontSet(display,
+				DEF_MESSAGEFONTSET,
+				&miss, &n_miss, &def);
+		}
+	}
 	return fs;
 }
 #endif
