@@ -10,7 +10,7 @@
  * mode.h - mode management for xlock, the X Window System lockscreen.
  *
  * Copyright (c) 1991 by Patrick J. Naughton.
- * xscreensaver code, Copyright (c) 1997 Jamie Zawinski <jwz@jwz.org>
+ * xscreensaver code, Copyright (c) 1997 Jamie Zawinski <jwz AT jwz.org>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -26,178 +26,14 @@
  *
  * Revision History:
  *
- * Changes maintained by David Bagley <bagleyd@tux.org>
- * 18-Mar-96: Ron Hitchens <ron@idiom.com>
+ * Changes maintained by David Bagley <bagleyd AT verizon.net>
+ * 18-Mar-96: Ron Hitchens <ron AT idiom.com>
  *		Extensive revision to define new data types for
  *		the new mode calling scheme.
  * 02-Jun-95: Extracted out of resource.c.
  *
  */
 
-/*-
- * Declare external interface routines for supported screen savers.
- */
-
-/* -------------------------------------------------------------------- */
-
-#ifdef STANDALONE
-
-/* xscreensaver compatibility layer for xlockmore modules. */
-
-/*-
- * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@jwz.org>
- *
- * Permission to use, copy, modify, distribute, and sell this software and its
- * documentation for any purpose is hereby granted without fee, provided that
- * the above copyright notice appear in all copies and that both that
- * copyright notice and this permission notice appear in supporting
- * documentation.  No representations are made about the suitability of this
- * software for any purpose.  It is provided "as is" without express or
- * implied warranty.
- *
- * The definitions in this file make it possible to compile an xlockmore
- * module into a standalone program, and thus use it with xscreensaver.
- * By Jamie Zawinski <jwz@jwz.org> on 10-May-97; based on the ideas
- * in the older xlock.h by Charles Hannum <mycroft@ai.mit.edu>.  (I had
- * to redo it, since xlockmore has diverged so far from xlock...)
- */
-
-/*-
- * Accessor macros for the ModeInfo structure
- */
-
-#define MI_DISPLAY(MI)		((MI)->dpy)
-#define MI_WINDOW(MI)		((MI)->window)
-#define MI_NUM_SCREENS(MI)	(1)	/* Only manage one screen at a time; */
-#define MI_SCREEN(MI)		(0)	/*  this might be fragile... */
-#define MI_NPIXELS(MI)		((MI)->npixels)
-#define MI_PIXEL(MI,N)		((MI)->pixels[(N)])
-#define MI_VISUAL(MI)		((MI)->xgwa.visual)
-#define MI_GC(MI)		((MI)->gc)
-#define MI_PAUSE(MI)		((MI)->pause)
-#define MI_LEFT_COLOR(MI)	((MI)->threed_left_color)
-#define MI_RIGHT_COLOR(MI)	((MI)->threed_right_color)
-#define MI_BOTH_COLOR(MI)	((MI)->threed_both_color)
-#define MI_NONE_COLOR(MI)	((MI)->threed_none_color)
-#define MI_DELTA3D(MI)		((MI)->threed_delta)
-#define MI_CYCLES(MI)		((MI)->cycles)
-#define MI_BATCHCOUNT(MI)	((MI)->count)
-#define MI_SIZE(MI)		((MI)->size)
-#define MI_BITMAP(MI)		((MI)->bitmap)
-#define MI_WHITE_PIXEL(MI)	((MI)->white)
-#define MI_BLACK_PIXEL(MI)	((MI)->black)
-#define MI_WIDTH(MI)	((MI)->xgwa.width)
-#define MI_HEIGHT(MI)	((MI)->xgwa.height)
-#define MI_DEPTH(MI)	((MI)->xgwa.depth)
-#define MI_COLORMAP(MI)	((MI)->xgwa.colormap)
-#define MI_IS_FULLRANDOM(MI)((MI)->fullrandom)
-#define MI_IS_DEBUG(MI)   ((MI)->verbose)
-#define MI_IS_VERBOSE(MI)   ((MI)->verbose)
-#define MI_IS_INSTALL(MI)   (True)
-#define MI_IS_MONO(MI)	(mono_p)
-#define MI_IS_INROOT(MI)	((MI)->root_p)
-#define MI_IS_INWINDOW(MI)	(!(MI)->root_p)
-#define MI_IS_ICONIC(MI)	(False)
-#define MI_IS_WIREFRAME(MI)	((MI)->wireframe_p)
-#define MI_IS_FPS(MI)	((MI)->fps_p)
-#define MI_IS_USE3D(MI)	((MI)->threed)
-#define MI_COUNT(MI)	((MI)->count)
-#define MI_NCOLORS(MI)    ((MI)->ncolors)
-#define MI_IS_DRAWN(MI)((MI)->is_drawn)
-
-
-#define MI_CLEARWINDOWCOLORMAP(mi, gc, pixel) \
-{ \
- XSetForeground(MI_DISPLAY(mi), gc, pixel); \
- XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc, \
-   0, 0, (unsigned int) MI_WIDTH(mi), (unsigned int) MI_HEIGHT(mi)); \
-}
-#define MI_CLEARWINDOWCOLORMAPFAST(mi, gc, pixel) \
- MI_CLEARWINDOWCOLORMAP(mi, gc, pixel)
-#define MI_CLEARWINDOWCOLOR(mi, pixel) \
- MI_CLEARWINDOWCOLORMAP(mi, MI_GC(mi), pixel)
-
-/* #define MI_CLEARWINDOW(mi) XClearWindow(MI_DISPLAY(mi), MI_WINDOW(mi)) */
-#define MI_CLEARWINDOW(mi) MI_CLEARWINDOWCOLOR(mi, MI_BLACK_PIXEL(mi))
-
-#include "screenhack.h"
-
-#ifdef __cplusplus
-  extern "C" {
-#endif
-typedef struct ModeInfo {
-	Display    *dpy;
-	Window      window;
-	Bool        root_p;
-	int         npixels;
-	unsigned long *pixels;
-	XColor     *colors;
-	int         polygon_count;
-	Bool        writable_p;
-	unsigned long white;
-	unsigned long black;
-	XWindowAttributes xgwa;
-	GC          gc;
-	long        pause;
-	Bool        fullrandom;
-	Bool        verbose;
-	int         count;
-	int         cycles;
-	int         size;
-	int         ncolors;
-	Bool        threed;
-	long        threed_left_color;
-	long        threed_right_color;
-	long        threed_both_color;
-	long        threed_none_color;
-	long        threed_delta;
-	Bool        wireframe_p;
-	char       *bitmap;
-	Bool        is_drawn;
-        Bool        fps_p;
-} ModeInfo;
-
-typedef enum {
-	t_String, t_Float, t_Int, t_Bool
-} xlockmore_type;
-
-typedef struct {
-	void       *var;
-	char       *name;
-	char       *classname;
-	char       *def;
-	xlockmore_type type;
-} argtype;
-
-typedef struct {
-	char       *opt;
-	char       *desc;
-} OptionStruct;
-
-typedef struct {
-	int         numopts;
-	XrmOptionDescRec *opts;
-	int         numvarsdesc;
-	argtype    *vars;
-	OptionStruct *desc;
-} ModeSpecOpt;
-
-extern void xlockmore_screenhack(Display * dpy, Window window,
-				 Bool want_writable_colors,
-				 Bool want_uniform_colors,
-				 Bool want_smooth_colors,
-				 Bool want_bright_colors,
-				 void        (*hack_init) (ModeInfo *),
-				 void        (*hack_draw) (ModeInfo *),
-				 void        (*hack_free) (ModeInfo *));
-#ifdef USE_GL
-extern Visual *get_gl_visual(Screen * screen, char *name, char *class);
-#endif
-#ifdef __cplusplus
-  }
-#endif
-
-#else /* STANDALONE */
 #ifdef __cplusplus
   extern "C" {
 #endif
@@ -214,7 +50,8 @@ typedef struct LockStruct_s {
 	ModeHook   *release_hook;	/* func to shutdown a mode */
 	ModeHook   *refresh_hook;	/* tells mode to repaint */
 	ModeHook   *change_hook;	/* user wants mode to change */
-	ModeHook   *unused_hook;	/* for future expansion */
+	/*ModeHook   *unused_hook;*/	/* future */
+	ModeHook   *free_hook;	/* free a single screen */
 	ModeSpecOpt *msopt;	/* this mode's def resources */
 	int         def_delay;	/* default delay for mode */
 	int         def_count;
@@ -226,6 +63,7 @@ typedef struct LockStruct_s {
 	char       *desc;	/* text description of mode */
 	unsigned int flags;	/* state flags for this mode */
 	void       *userdata;	/* for use by the mode */
+	void       **state_array;	/* array of per-screen state, set from MI_INIT */
 } LockStruct;
 
 #define LS_FLAG_INITED		1
@@ -274,6 +112,7 @@ typedef struct {
 	XWindowChanges fullsizeconfigure;
 	mboxInfo    mb;
 	Pixmap	    root_pixmap;
+	double      recursion_depth;
 } ScreenInfo;
 
 typedef struct {
@@ -403,6 +242,7 @@ typedef struct ModeInfo_s {
 #define MI_RIGHT_COLOR(mi)	((mi)->screeninfo->right_pixel)
 #define MI_LEFT_COLOR(mi)	((mi)->screeninfo->left_pixel)
 #define MI_ROOT_PIXMAP(mi)	((mi)->screeninfo->root_pixmap)
+#define MI_RECURSION_DEPTH(MI)	((mi)->screeninfo->recursion_depth)
 
 #define MI_DELAY(mi)		((mi)->runinfo.delay)
 #define MI_COUNT(mi)		((mi)->runinfo.count)
@@ -431,7 +271,7 @@ typedef struct ModeInfo_s {
  * It was acting weird with the first rectangle drawn
  * on a Ultra2 with TrueColor Solaris2.x in deco mode.
  * Not sure if other modes are affected... now handled in deco mode.
- * If it does happen it is probably not as noticable to worry about.
+ * If it does happen it is probably not as noticeable to worry about.
  */
 #endif
 
@@ -481,6 +321,7 @@ extern HookProc call_callback_hook;
 extern HookProc call_release_hook;
 extern HookProc call_refresh_hook;
 extern HookProc call_change_hook;
+/*extern HookProc call_unused_hook;*/
 
 extern void set_default_mode(LockStruct *);
 extern void release_last_mode(ModeInfo *);
@@ -492,6 +333,7 @@ extern void release_last_mode(ModeInfo *);
 #ifndef NICE_ONLY
 /* comment out following defines to remove modes */
 #ifdef USE_GL
+#define MODE_boxed
 #define MODE_cage
 #define MODE_fire
 #define MODE_gears
@@ -500,6 +342,9 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_juggler3d
 #endif
 #define MODE_lament
+#ifdef HAVE_LIBPNG
+#define MODE_maze3d
+#endif
 #define MODE_moebius
 #ifndef WIN32
 #define MODE_molecule
@@ -542,9 +387,7 @@ extern void release_last_mode(ModeInfo *);
 #ifdef USE_UNSTABLE
 #define MODE_run /* VMS problems as well as -debug problems */
 #endif	/* USE_UNSTABLE */
-#ifndef WIN32
 #define MODE_anemone
-#endif
 #define MODE_ant
 #define MODE_ant3d
 #define MODE_apollonian
@@ -554,15 +397,12 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_bouboule
 #define MODE_bounce
 #define MODE_braid
-#ifndef WIN32
 #define MODE_bubble
-#endif /* !WIN32 */
 #define MODE_bug
 #define MODE_clock
 #define MODE_coral
 #define MODE_crystal
 #define MODE_daisy
-#ifndef WIN32
 #define MODE_dclock
 /*-
  * Comment out dclock sub-modes to disable them from random selection.
@@ -571,12 +411,11 @@ extern void release_last_mode(ModeInfo *);
  */
 /* #define MODE_dclock_y2k */
 /* #define MODE_dclock_millennium */
+#ifndef WIN32
 #define MODE_decay
 #endif /* !WIN32 */
 #define MODE_deco
-#ifndef WIN32
 #define MODE_deluxe
-#endif /* !WIN32 */
 #define MODE_demon
 #define MODE_dilemma
 #define MODE_discrete
@@ -604,9 +443,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_hop
 #define MODE_hyper
 #define MODE_ico
-#ifndef WIN32
 #define MODE_ifs
-#endif /* !WIN32 */
 #define MODE_image
 #define MODE_juggle
 #define MODE_julia
@@ -654,12 +491,12 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_spline
 #define MODE_star
 #define MODE_starfish
-#ifndef WIN32
 #define MODE_strange
-#endif /* !WIN32 */
 #define MODE_swarm
 #ifndef WIN32
 #define MODE_swirl
+#endif /* !WIN32 */
+#ifndef WIN32
 #define MODE_t3d
 #endif /* !WIN32 */
 #define MODE_tetris
@@ -760,7 +597,7 @@ extern void release_last_mode(ModeInfo *);
 extern ModeHook init_anemone;
 extern ModeHook draw_anemone;
 extern ModeHook release_anemone;
-extern ModeHook refresh_anemone;
+extern ModeHook free_anemone;
 extern ModeSpecOpt anemone_opts;
 #endif
 
@@ -769,6 +606,7 @@ extern ModeHook init_ant;
 extern ModeHook draw_ant;
 extern ModeHook release_ant;
 extern ModeHook refresh_ant;
+extern ModeHook free_ant;
 extern ModeSpecOpt ant_opts;
 #endif
 
@@ -777,6 +615,7 @@ extern ModeHook init_ant3d;
 extern ModeHook draw_ant3d;
 extern ModeHook release_ant3d;
 extern ModeHook refresh_ant3d;
+extern ModeHook free_ant3d;
 extern ModeSpecOpt ant3d_opts;
 #endif
 
@@ -785,6 +624,7 @@ extern ModeHook init_apollonian;
 extern ModeHook draw_apollonian;
 extern ModeHook release_apollonian;
 extern ModeHook refresh_apollonian;
+extern ModeHook free_apollonian;
 extern ModeSpecOpt apollonian_opts;
 #endif
 
@@ -792,7 +632,6 @@ extern ModeSpecOpt apollonian_opts;
 extern ModeHook init_atlantis;
 extern ModeHook draw_atlantis;
 extern ModeHook release_atlantis;
-extern ModeHook refresh_atlantis;
 extern ModeHook change_atlantis;
 extern ModeSpecOpt atlantis_opts;
 #endif
@@ -801,7 +640,6 @@ extern ModeSpecOpt atlantis_opts;
 extern ModeHook init_atunnels;
 extern ModeHook draw_atunnels;
 extern ModeHook release_atunnels;
-extern ModeHook refresh_atunnels;
 extern ModeHook change_atunnels;
 extern ModeSpecOpt atunnels_opts;
 #endif
@@ -811,6 +649,7 @@ extern ModeHook init_ball;
 extern ModeHook draw_ball;
 extern ModeHook release_ball;
 extern ModeHook refresh_ball;
+extern ModeHook free_ball;
 extern ModeSpecOpt ball_opts;
 #endif
 
@@ -819,6 +658,7 @@ extern ModeHook init_bat;
 extern ModeHook draw_bat;
 extern ModeHook release_bat;
 extern ModeHook refresh_bat;
+extern ModeHook free_bat;
 extern ModeSpecOpt bat_opts;
 #endif
 
@@ -835,6 +675,7 @@ extern ModeHook init_blot;
 extern ModeHook draw_blot;
 extern ModeHook release_blot;
 extern ModeHook refresh_blot;
+extern ModeHook free_blot;
 extern ModeSpecOpt blot_opts;
 #endif
 
@@ -854,6 +695,13 @@ extern ModeHook refresh_bounce;
 extern ModeSpecOpt bounce_opts;
 #endif
 
+#ifdef MODE_boxed
+extern ModeHook init_boxed;
+extern ModeHook draw_boxed;
+extern ModeHook release_boxed;
+extern ModeSpecOpt boxed_opts;
+#endif
+
 #ifdef MODE_braid
 extern ModeHook init_braid;
 extern ModeHook draw_braid;
@@ -866,7 +714,7 @@ extern ModeSpecOpt braid_opts;
 extern ModeHook init_bubble;
 extern ModeHook draw_bubble;
 extern ModeHook release_bubble;
-extern ModeHook refresh_bubble;
+extern ModeHook free_bubble;
 extern ModeSpecOpt bubble_opts;
 #endif
 
@@ -874,7 +722,6 @@ extern ModeSpecOpt bubble_opts;
 extern ModeHook init_bubble3d;
 extern ModeHook draw_bubble3d;
 extern ModeHook release_bubble3d;
-extern ModeHook change_bubble3d;
 extern ModeSpecOpt bubble3d_opts;
 #endif
 
@@ -962,7 +809,6 @@ extern ModeSpecOpt deco_opts;
 extern ModeHook init_deluxe;
 extern ModeHook draw_deluxe;
 extern ModeHook release_deluxe;
-extern ModeHook refresh_deluxe;
 extern ModeSpecOpt deluxe_opts;
 #endif
 
@@ -1031,6 +877,14 @@ extern ModeHook refresh_fadeplot;
 extern ModeSpecOpt fadeplot_opts;
 #endif
 
+#ifdef MODE_fiberlamp
+extern ModeHook init_fiberlamp;
+extern ModeHook draw_fiberlamp;
+extern ModeHook release_fiberlamp;
+extern ModeHook change_fiberlamp;
+extern ModeSpecOpt fiberlamp_opts;
+#endif
+
 #ifdef MODE_fire
 extern ModeHook init_fire;
 extern ModeHook draw_fire;
@@ -1040,14 +894,6 @@ extern ModeHook change_fire;
 extern ModeSpecOpt fire_opts;
 #endif
 
-#ifdef MODE_fiberlamp
-extern ModeHook init_fiberlamp;
-extern ModeHook draw_fiberlamp;
-extern ModeHook release_fiberlamp;
-extern ModeHook change_fiberlamp;
-extern ModeSpecOpt fiberlamp_opts;
-#endif
-
 #ifdef MODE_flag
 extern ModeHook init_flag;
 extern ModeHook draw_flag;
@@ -1207,14 +1053,6 @@ extern ModeHook refresh_julia;
 extern ModeSpecOpt julia_opts;
 #endif
 
-#ifdef MODE_kaleid2
-extern ModeHook init_kaleid2;
-extern ModeHook draw_kaleid2;
-extern ModeHook release_kaleid2;
-extern ModeHook refresh_kaleid2;
-extern ModeSpecOpt kaleid2_opts;
-#endif
-
 #ifdef MODE_kaleid
 extern ModeHook init_kaleid;
 extern ModeHook draw_kaleid;
@@ -1223,6 +1061,14 @@ extern ModeHook refresh_kaleid;
 extern ModeSpecOpt kaleid_opts;
 #endif
 
+#ifdef MODE_kaleid2
+extern ModeHook init_kaleid2;
+extern ModeHook draw_kaleid2;
+extern ModeHook release_kaleid2;
+extern ModeHook refresh_kaleid2;
+extern ModeSpecOpt kaleid2_opts;
+#endif
+
 #ifdef MODE_kumppa
 extern ModeHook init_kumppa;
 extern ModeHook draw_kumppa;
@@ -1243,6 +1089,7 @@ extern ModeHook init_laser;
 extern ModeHook draw_laser;
 extern ModeHook release_laser;
 extern ModeHook refresh_laser;
+extern ModeHook free_laser;
 extern ModeSpecOpt laser_opts;
 #endif
 
@@ -1252,6 +1099,7 @@ extern ModeHook draw_life;
 extern ModeHook release_life;
 extern ModeHook refresh_life;
 extern ModeHook change_life;
+extern ModeHook free_life;
 extern ModeSpecOpt life_opts;
 #endif
 
@@ -1260,6 +1108,7 @@ extern ModeHook init_life1d;
 extern ModeHook draw_life1d;
 extern ModeHook release_life1d;
 extern ModeHook refresh_life1d;
+extern ModeHook free_life1d;
 extern ModeSpecOpt life1d_opts;
 #endif
 
@@ -1269,6 +1118,7 @@ extern ModeHook draw_life3d;
 extern ModeHook release_life3d;
 extern ModeHook refresh_life3d;
 extern ModeHook change_life3d;
+extern ModeHook free_life3d;
 extern ModeSpecOpt life3d_opts;
 #endif
 
@@ -1276,7 +1126,6 @@ extern ModeSpecOpt life3d_opts;
 extern ModeHook init_lightning;
 extern ModeHook draw_lightning;
 extern ModeHook release_lightning;
-extern ModeHook refresh_lightning;
 extern ModeSpecOpt lightning_opts;
 #endif
 
@@ -1345,6 +1194,13 @@ extern ModeHook refresh_maze;
 extern ModeSpecOpt maze_opts;
 #endif
 
+#ifdef MODE_maze3d
+extern ModeHook init_maze3d;
+extern ModeHook draw_maze3d;
+extern ModeHook release_maze3d;
+extern ModeSpecOpt maze3d_opts;
+#endif
+
 #ifdef MODE_moebius
 extern ModeHook init_moebius;
 extern ModeHook draw_moebius;
@@ -1483,6 +1339,7 @@ extern ModeHook init_qix;
 extern ModeHook draw_qix;
 extern ModeHook release_qix;
 extern ModeHook refresh_qix;
+extern ModeHook free_qix;
 extern ModeSpecOpt qix_opts;
 #endif
 
@@ -1590,7 +1447,6 @@ extern ModeSpecOpt solitaire_opts;
 extern ModeHook init_space;
 extern ModeHook draw_space;
 extern ModeHook release_space;
-extern ModeHook refresh_space;
 extern ModeSpecOpt space_opts;
 #endif
 
@@ -1622,7 +1478,6 @@ extern ModeSpecOpt spline_opts;
 extern ModeHook init_sproingies;
 extern ModeHook draw_sproingies;
 extern ModeHook release_sproingies;
-extern ModeHook refresh_sproingies;
 extern ModeSpecOpt sproingies_opts;
 #endif
 
@@ -1661,7 +1516,6 @@ extern ModeSpecOpt strange_opts;
 extern ModeHook init_superquadrics;
 extern ModeHook draw_superquadrics;
 extern ModeHook release_superquadrics;
-extern ModeHook refresh_superquadrics;
 extern ModeSpecOpt superquadrics_opts;
 #endif
 
@@ -1828,16 +1682,12 @@ extern ModeSpecOpt xjack_opts;
 #endif
 
 extern ModeHook init_blank;
-extern ModeHook draw_blank;
-extern ModeHook release_blank;
-extern ModeHook refresh_blank;
 extern ModeSpecOpt blank_opts;
 
 #ifdef MODE_run
 extern ModeHook init_run;
-extern ModeHook draw_run;
 extern ModeHook release_run;
-extern ModeHook refresh_run;
+extern ModeHook free_run;
 extern ModeSpecOpt run_opts;
 #endif
 
@@ -1875,6 +1725,14 @@ extern int  numprocs;
   }
 #endif
 
-#endif /* STANDALONE */
-/* -------------------------------------------------------------------- */
+#define MI_INIT(mi, state_array) \
+  { \
+    mi_init ((mi), sizeof(*(state_array)), (void **)&(state_array)); \
+    if (!state_array) \
+      return; \
+  }
+extern void mi_init (ModeInfo *, size_t, void **);
+
+#define XSCREENSAVER_MODULE(CLASS,PREFIX)
+
 #endif /* __XLOCK_MODE_H__ */
