@@ -10,7 +10,7 @@ static const char sccsid[] = "@(#)passwd.c	5.00 2000/11/01 xlockmore";
  *
  * Revision History:
  *
- * Changes maintained by David Bagley <bagleyd@tux.org>
+ * Changes maintained by David Bagley <bagleyd AT verizon.net>
  * 23-Feb-2003: Timothy Reed <treed1@twcny.rr.com>
  *              Updated PAM_conv to call over to xlock to display messages
  *              and return responses to the calling PAM
@@ -28,11 +28,11 @@ static const char sccsid[] = "@(#)passwd.c	5.00 2000/11/01 xlockmore";
  *              Added in ability for any of the root accounts to unlock
  *              screen.  Message now gets sent to syslog if root does the
  *              unlocking.
- * 23-Dec-1995: Ron Hitchens <ron@idiom.com> reorganized.
+ * 23-Dec-1995: Ron Hitchens <ron AT idiom.com> reorganized.
  * 10-Dec-1995: More context handling stuff for DCE thanks to
  *              Terje Marthinussen <terjem@cc.uit.no>.
  * 01-Sep-1995: DCE code added thanks to Heath A. Kehoe
- *              <hakehoe@icaen.uiowa.edu>.
+ *              <hakehoe AT icaen.uiowa.edu>.
  * 24-Jun-1995: Extracted from xlock.c, encrypted passwords are now fetched
  *              on start-up to ensure correct operation (except Ultrix).
  */
@@ -60,7 +60,7 @@ extern char *cpasswd;
 #include <X11/Xlib.h>
 #endif
 
-#if defined(__CYGWIN__) || defined(SOLARIS2)
+#if defined( CYGWIN ) || defined( SOLARIS2 )
 #include <crypt.h>
 #endif
 
@@ -302,20 +302,22 @@ PAM_conv(int num_msg,
 
 #define COPY_STRING(s) (s) ? strdup(s) : NULL
 
-	reply = (struct pam_response *) malloc(sizeof (struct pam_response) *
-					       num_msg);
-
-// reply[] members is not initialized!
-// As a result - abort trap when PAM tries to free reply structure
-// after PAM_ERROR_MSG processing.
+	reply = (struct pam_response *) calloc(num_msg,
+					       sizeof (struct pam_response));
 
+/*
+ * reply[] members is not initialized!
+ * As a result - abort trap when PAM tries to free reply structure
+ * after PAM_ERROR_MSG processing.
+ */
 	if (!reply)
 		return PAM_BUF_ERR;
 
-// So I just initialize reply here with default values and drop
-// initialization from code below (if code matches).
-
-	reply[replies].resp_retcode = PAM_SUCCESS; // be optimistic
+/*
+ * So I just initialize reply here with default values and drop
+ * initialization from code below (if code matches).
+ */
+	reply[replies].resp_retcode = PAM_SUCCESS; /* be optimistic */
 	reply[replies].resp = NULL;
 
 	for (replies = 0; replies < num_msg; replies++) {
@@ -335,29 +337,36 @@ PAM_conv(int num_msg,
 #ifdef DEBUG
 				(void) printf( " + Message style: PAM_PROMPT_ECHO_OFF\n" );
 #endif
+/* Hard coding "Password"  is an issue for  non-English locales. */
+/* A list of prompts should be obtained at initial phase of authentication. */
+#ifdef PAM_PASSWORD_PROMPT
 				if( strstr( msg[replies]->msg, "Password" ) == NULL ) {
 					PAM_putText( msg[replies], &reply[replies], False );
-				} else {
+				} else
+#endif
 					reply[replies].resp = COPY_STRING(PAM_password);
-				}
 				/* PAM frees resp */
 				break;
 			case PAM_TEXT_INFO:
 #ifdef DEBUG
 				(void) printf( " + Message style: PAM_TEXT_INFO\n" );
 #endif
+#ifdef PAM_PASSWORD_PROMPT
 				if( strstr( msg[replies]->msg, "Password" ) == NULL ) {
 					PAM_putText( msg[replies], &reply[replies], False );
 				}
+#endif
 				/* PAM frees resp */
 				break;
 			case PAM_ERROR_MSG:
 #ifdef DEBUG
 				(void) printf( " + Message style: PAM_ERROR_MSG\n" );
 #endif
+#ifdef PAM_PASSWORD_PROMPT
 				if( strstr( msg[replies]->msg, "Password" ) == NULL ) {
 					PAM_putText( msg[replies], &reply[replies], False );
 				}
+#endif
 				/* PAM frees resp */
 				break;
 			default:
@@ -531,7 +540,7 @@ getUserName(void)
 /*-
  * The PasswdEtc libraries have replacement passwd functions that make
  * queries to DomainOS registries.  Unfortunately, these functions do
- * wierd things to the process (at minimum, signal handlers get changed,
+ * weird things to the process (at minimum, signal handlers get changed,
  * there are probably other things as well) that cause xlock to become
  * unstable.
  *
@@ -747,7 +756,7 @@ gpass(void)
 				&& buf[0] == '*') ||
 #endif
 			       (strlen(buf) == CPASSLENGTH && buf[CPASSLENGTH - 1] == '\n')))) {
-				(void) fprintf(stderr, "%s: %s crypted password %s\n", xlockrc,
+				(void) fprintf(stderr, "%s: %s encrypted password %s\n", xlockrc,
 				       buf[0] == '\0' ? "null" : "bad", buf);
 #if defined(HAVE_KRB4) || defined(HAVE_KRB5)
 				if (!gpasskey(buf)) {
@@ -766,7 +775,7 @@ gpass(void)
 	} else {
 
 		if (strlen(cpasswd) != CPASSLENGTH - 1) {
-			(void) fprintf(stderr, "%s: bad crypted password %s\n",
+			(void) fprintf(stderr, "%s: bad encrypted password %s\n",
 				       ProgramName, cpasswd);
 			exit(1);
 		} else
@@ -1422,11 +1431,10 @@ checkPasswd(char *buffer)
 #endif
 			!strcmp((char *) crptpass, rootpass)) {
 		done = True;
-		if (!(rootpass != NULL && *buffer))
+		if (!*rootpass && *buffer)
 			/*
 			 * root has no password, don't let him in...
 			 */
-
 			done = False;
 #if ( HAVE_SYSLOG_H && defined( USE_SYSLOG ))
 		else
@@ -1456,9 +1464,9 @@ checkPasswd(char *buffer)
  *
  * Revision History:
  * 21-Aug-95: Added fallback to static password file [HAK]
- * 06-Jul-95: Mods by Heath A. Kehoe <hakehoe@icaen.uiowa.edu> for
+ * 06-Jul-95: Mods by Heath A. Kehoe <hakehoe AT icaen.uiowa.edu> for
  *            inclusion into xlockmore
- * May-95: Created by Phil O'Connell <philo@icaen.uiowa.edu>
+ * May-95: Created by Phil O'Connell <philo AT icaen.uiowa.edu>
  */
 
 #ifdef DCE_PASSWD
@@ -1617,7 +1625,7 @@ error_string(error_status_t error_status)
  *       Server used to set up and validate a login context is legitimate.
  *
  *       Created by Phil O'Connell
- *     philo@icaen.uiowa.edu
+ *     philo AT icaen.uiowa.edu
  *     Student Programmer
  *
  *-----------------------------------------------------------------------
