@@ -1,4 +1,4 @@
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
 
 #endif
@@ -12,32 +12,32 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
  *
  * Revision History:
  *
- * Changes maintained by David Bagley <bagleyd@tux.org>
- * 02-Dec-03: Jouk Jansen <joukj@hrem.stm.tudelft.nl>
+ * Changes maintained by David Bagley <bagleyd AT verizon.net>
+ * 02-Dec-03: Jouk Jansen <joukj AT hrem.nano.tudelft.nl>
  *            On OpenVMS when TCPIP is switched off gethostname does not
  *            work, in that case LIB$GETSYI to get the DECNET nodename.
  * 19-Jun-98: batchcount deprecated.  Use count instead.  batchcount still
  *            works for commandline.
  * 01-May-97: Matthew Rench <mdrench@mtu.edu>
  *            Added DPMS options.
- * 01-Apr-97: Tom Schmidt <tschmidt@micron.com>
+ * 01-Apr-97: Tom Schmidt <tschmidt AT micron.com>
  *            Fixed memory leak.  Made -visual option a hacker mode for now.
- * 20-Mar-97: Tom Schmidt <tschmidt@micron.com>
+ * 20-Mar-97: Tom Schmidt <tschmidt AT micron.com>
  *            Added -visual option.
- *  3-Apr-96: Jouk Jansen <joukj@hrem.stm.tudelft.nl>
+ *  3-Apr-96: Jouk Jansen <joukj AT hrem.nano.tudelft.nl>
  *            Supply for wildcards for filenames for random selection
- * 18-Mar-96: Ron Hitchens <ron@idiom.com>
+ * 18-Mar-96: Ron Hitchens <ron AT idiom.com>
  *            Setup chosen mode with set_default_mode() for new hook scheme.
- *  6-Mar-96: Jouk Jansen <joukj@hrem.stm.tudelft.nl>
+ *  6-Mar-96: Jouk Jansen <joukj AT hrem.nano.tudelft.nl>
  *            Remote node checking for VMS fixed
- * 20-Dec-95: Ron Hitchens <ron@idiom.com>
+ * 20-Dec-95: Ron Hitchens <ron AT idiom.com>
  *            Resource parsing fixed for "nolock".
  * 02-Aug-95: Patch to use default delay, etc., from mode.h thanks to
  *            Roland Bock <exp120@physik.uni-kiel.d400.de>
  * 17-Jun-95: Split out mode.h from resource.c .
  * 29-Mar-95: Added -cycles for more control over a lockscreen similar to
  *            -delay, -batchcount, and -saturation.
- * 21-Feb-95: MANY patches from Heath A. Kehoe <hakehoe@icaen.uiowa.edu>.
+ * 21-Feb-95: MANY patches from Heath A. Kehoe <hakehoe AT icaen.uiowa.edu>.
  * 21-Dec-94: patch for -delay, -batchcount and -saturation for X11R5+
  *            from Patrick D Sullivan <pds@bss.com>.
  * 18-Dec-94: -inroot option added from Bill Woodward <wpwood@pencom.com>.
@@ -169,11 +169,11 @@ static int  descr();
 #ifdef USE_MB
 # define DEF_FONTSET	DEF_FONT ",-*-*-medium-r-normal--24-*"
 # define DEF_PLANFONTSET DEF_PLANFONT ",-*-*-medium-r-normal--14-*"
-#endif /* USE NONASCII */
+#endif /* USE_MB */
 #define DEF_BG		"White"
 #define DEF_FG		"Black"
 
-/* language dependant resources */
+/* language dependent resources */
 #if defined FR
 #include "resource-msg-fr.h"
 #elif defined NL
@@ -226,7 +226,7 @@ static int  descr();
 #define DEF_CLASSNAME	"XLock"
 #if 0
 /*-
-  Grid     Number of Neigbors
+  Grid     Number of Neighbors
   ----     ------------------
   Square   4 or 8
   Hexagon  6
@@ -237,30 +237,24 @@ static int  descr();
 #endif
 
 #ifdef USE_RPLAY
-# define DEF_LOCKSOUND	"thank-you"
-# define DEF_INFOSOUND	"identify-please"
-# define DEF_VALIDSOUND	"complete"
+# define DEF_LOCKSOUND		"thank-you"
+# define DEF_INFOSOUND		"identify-please"
+# define DEF_VALIDSOUND		"complete"
 # define DEF_INVALIDSOUND	"not-programmed"
 #else /* !USE_RPLAY */
-# if defined ( DEF_PLAY ) || defined ( USE_NAS )
-#  define DEF_LOCKSOUND	"thank-you.au"
-#  define DEF_INFOSOUND	"identify-please.au"
+# if defined ( DEF_PLAY ) || defined ( USE_NAS ) || defined ( USE_ESOUND )
+#  define DEF_LOCKSOUND		"thank-you.au"
+#  define DEF_INFOSOUND		"identify-please.au"
 #  define DEF_VALIDSOUND	"complete.au"
 #  define DEF_INVALIDSOUND	"not-programmed.au"
-# else /* !DEF_PLAY && !USE_NAS */
+# else /* !DEF_PLAY && !USE_NAS && !USE_ESOUND */
 #  ifdef USE_VMSPLAY
 #   define DEF_LOCKSOUND	"[]thank-you.au"
 #   define DEF_INFOSOUND	"[]identify-please.au"
 #   define DEF_VALIDSOUND	"[]complete.au"
 #   define DEF_INVALIDSOUND	"[]not-programmed.au"
 #  endif /* !USE_VMSPLAY */
-#  ifdef USE_ESOUND
-#   define DEF_LOCKSOUND 	"thank-you.au"
-#   define DEF_INFOSOUND	"identify-please.au"
-#   define DEF_VALIDSOUND	"complete.au"
-#   define DEF_INVALIDSOUND	"not-programmed.au"
-#  endif
-# endif /* !DEF_PLAY && !USE_NAS */
+# endif /* !DEF_PLAY && !USE_NAS && !USE_ESOUND */
 #endif /* !USE_RPLAY */
 
 #if defined( USE_AUTO_LOGOUT ) && !defined( DEF_AUTO_LOGOUT )
@@ -1027,6 +1021,8 @@ static argtype modevars[] =
 
 #define NMODEARGS (sizeof modevars / sizeof modevars[0])
 
+extern void checkResources(void);
+
 static int  modevaroffs[NMODEARGS] =
 {
 	offsetof(LockStruct, def_delay),
@@ -1117,9 +1113,13 @@ Help(void)
 
 		(void) printf("          %-23s %s\n",
 			      LockProcs[i].cmdline_arg, LockProcs[i].desc);
-		for (j = 0; j < LockProcs[i].msopt->numvarsdesc; j++)
+		for (j = 0; j < LockProcs[i].msopt->numvarsdesc; j++) {
+			if (LockProcs[i].msopt->desc == NULL)
+				continue;
 			(void) printf("              %-23s %s\n",
-				      LockProcs[i].msopt->desc[j].opt, LockProcs[i].msopt->desc[j].desc);
+				LockProcs[i].msopt->desc[j].opt,
+				LockProcs[i].msopt->desc[j].desc);
+		}
 	}
 	(void) printf("\n");
 
@@ -1963,7 +1963,7 @@ getResources(Display ** displayp, int argc, char **argv)
 
 		if (!ms->numopts)
 			continue;
-                 /*     Runnning real XrmParseCommand on a nullDB to set argv
+                 /*     Running real XrmParseCommand on a nullDB to set argv
                         and argc.
                  */
 		XrmParseCommand(&nullDB, ms->opts, ms->numopts,
